=== modified file '.bzrignore'
--- .bzrignore	2009-07-31 19:56:19 +0000
+++ .bzrignore	2009-09-09 11:43:10 +0000
@@ -5,10 +5,21 @@
 ./.bzr.log
 # Generated files
 CHANGELOG
+# generated documents
 bzr.1
 ./doc/*.html
-./doc/_build/
+./doc/*/_build/
+./doc/*/Makefile
+./doc/*/make.bat
 ./tutorial.html
+./build_doc_website
+./html_docs
+./pretty_docs
+./api
+./doc/**/*.html
+./doc/developers/performance.png
+./doc/en/user-reference/*.txt
+./doc/en/release-notes/*.txt
 BRANCH-INFO
 # setup.py working directory
 ./build
@@ -35,11 +46,7 @@
 ./dist
 # performance history data file
 ./.perf_history
-./html_docs
-./pretty_docs
-./api
-doc/**/*.html
-doc/developers/performance.png
+# Pyrex
 bzrlib/_annotator_pyx.c
 bzrlib/_bencode_pyx.c
 bzrlib/_btree_serializer_pyx.c
@@ -52,15 +59,8 @@
 bzrlib/_readdir_pyx.c
 bzrlib/_rio_pyx.c
 bzrlib/_walkdirs_win32.c
-doc/en/release-notes/NEWS.txt
-doc/en/developer-guide/HACKING.txt
-doc/en/user-reference/bzr_man.txt
 # built extension modules
 bzrlib/_*.dll
 bzrlib/_*.so
 bzrlib/_*.pyd
-# generated help topics
-doc/en/user-reference/*.txt
-./doc/en/user-guide/latex_prepared
-./doc/en/user-guide/*.pdf
 ./.ccache

=== modified file 'Makefile'
--- Makefile	2009-08-27 00:53:27 +0000
+++ Makefile	2009-09-11 07:55:48 +0000
@@ -75,40 +75,157 @@
 # these are treated as phony so they'll always be rebuilt - it's pretty quick
 .PHONY: TAGS tags
 
+
 ### Documentation ###
 
-# set PRETTY to get docs that look like the Bazaar web site
-ifdef PRETTY
-rst2html := $(PYTHON) tools/rst2prettyhtml.py doc/bazaar-vcs.org.kid 
-else
+# Default to plain documentation for maximum backwards compatibility.
+# (Post 2.0, the defaults will most likely be Sphinx-style instead.)
+
+docs: docs-plain
+
+clean-docs: clean-plain
+
+html-docs: html-plain
+
+
+### Man-page Documentation ###
+
+MAN_DEPENDENCIES = bzrlib/builtins.py \
+	$(wildcard bzrlib/*.py) \
+	$(wildcard bzrlib/*/*.py) \
+	tools/generate_docs.py \
+	$(wildcard $(addsuffix /*.txt, bzrlib/help_topics/en)) 
+
+MAN_PAGES = man1/bzr.1
+man1/bzr.1: $(MAN_DEPENDENCIES)
+	$(PYTHON) tools/generate_docs.py -o $@ man
+
+
+### Sphinx-style Documentation ###
+
+# Build the documentation. To keep the dependencies down to a minimum
+# for distro packagers, we only build the html documentation by default.
+# Sphinx 0.6 or later is preferred for the best rendering, though
+# Sphinx 0.4 or later should work. See http://sphinx.pocoo.org/index.html
+# for installation instructions.
+docs-sphinx: html-sphinx
+
+# Clean out generated documentation
+clean-sphinx:
+	cd doc/en && make clean
+	cd doc/es && make clean
+	cd doc/ru && make clean
+	cd doc/developers && make clean
+
+SPHINX_DEPENDENCIES = \
+        doc/en/release-notes/index.txt \
+        doc/en/user-reference/index.txt \
+	doc/es/Makefile \
+	doc/es/make.bat \
+	doc/ru/Makefile \
+	doc/ru/make.bat \
+	doc/developers/Makefile \
+	doc/developers/make.bat
+
+doc/en/user-reference/index.txt: $(MAN_DEPENDENCIES)
+	$(PYTHON) tools/generate_docs.py -o $@ rstx
+
+doc/en/release-notes/index.txt: NEWS tools/generate_release_notes.py
+	$(PYTHON) tools/generate_release_notes.py NEWS $@
+
+doc/%/Makefile: doc/en/Makefile
+	$(PYTHON) -c "import shutil; shutil.copyfile('$<', '$@')"
+
+doc/%/make.bat: doc/en/make.bat
+	$(PYTHON) -c "import shutil; shutil.copyfile('$<', '$@')"
+
+# Build the html docs using Sphinx.
+html-sphinx: $(SPHINX_DEPENDENCIES)
+	cd doc/en && make html
+	cd doc/es && make html
+	cd doc/ru && make html
+	cd doc/developers && make html
+
+# Build the PDF docs using Sphinx. This requires numerous LaTeX
+# packages. See http://sphinx.pocoo.org/builders.html for details.
+# Note: We don't currently build PDFs for the Russian docs because
+# they require additional packages to be installed (to handle
+# Russian hyphenation rules, etc.)
+pdf-sphinx: $(SPHINX_DEPENDENCIES)
+	cd doc/en && make latex
+	cd doc/es && make latex
+	cd doc/developers && make latex
+	cd doc/en/_build/latex && make all-pdf
+	cd doc/es/_build/latex && make all-pdf
+	cd doc/developers/_build/latex && make all-pdf
+
+# Build the CHM (Windows Help) docs using Sphinx.
+# Note: HtmlHelp Workshop needs to be used on the generated hhp files
+# to generate the final chm files.
+chm-sphinx: $(SPHINX_DEPENDENCIES)
+	cd doc/en && make htmlhelp
+	cd doc/es && make htmlhelp
+	cd doc/ru && make htmlhelp
+	cd doc/developers && make htmlhelp
+
+
+### Documentation Website ###
+
+# Where to build the website
+DOC_WEBSITE_BUILD := build_doc_website
+
+# Build and package docs into a website, complete with downloads.
+doc-website: html-sphinx pdf-sphinx
+	$(PYTHON) tools/package_docs.py doc/en $(DOC_WEBSITE_BUILD)
+	$(PYTHON) tools/package_docs.py doc/es $(DOC_WEBSITE_BUILD)
+	$(PYTHON) tools/package_docs.py doc/ru $(DOC_WEBSITE_BUILD)
+	$(PYTHON) tools/package_docs.py doc/developers $(DOC_WEBSITE_BUILD)
+
+
+### Plain Documentation ###
+
+# While Sphinx is the preferred tool for building documentation, we still
+# support our "plain" html documentation so that Sphinx is not a hard
+# dependency for packagers on older platforms.
+
 rst2html := $(PYTHON) tools/rst2html.py --link-stylesheet --footnote-references=superscript --halt=warning
-endif
 
 # translate txt docs to html
 derived_txt_files := \
 	doc/en/user-reference/bzr_man.txt \
 	doc/en/release-notes/NEWS.txt
-txt_files := \
+txt_all := \
 	doc/en/tutorials/tutorial.txt \
 	doc/en/tutorials/using_bazaar_with_launchpad.txt \
 	doc/en/tutorials/centralized_workflow.txt \
+        $(wildcard doc/es/tutorials/*.txt) \
         $(wildcard doc/ru/tutorials/*.txt) \
 	$(wildcard doc/*/mini-tutorial/index.txt) \
-	$(wildcard doc/*/user-guide/index.txt) \
+	$(wildcard doc/*/user-guide/index-plain.txt) \
+	$(wildcard doc/es/guia-usario/*.txt) \
 	$(derived_txt_files) \
-	doc/en/developer-guide/HACKING.txt \
 	doc/en/upgrade-guide/index.txt \
-	$(wildcard doc/es/guia-usario/*.txt) \
-	doc/es/mini-tutorial/index.txt \
 	doc/index.txt \
 	$(wildcard doc/index.*.txt)
+txt_nohtml := \
+	doc/en/user-guide/index.txt \
+	doc/es/user-guide/index.txt \
+	doc/ru/user-guide/index.txt
+txt_files := $(filter-out $(txt_nohtml), $(txt_all))
+htm_files := $(patsubst %.txt, %.html, $(txt_files)) 
+
 non_txt_files := \
        doc/default.css \
-       $(wildcard doc/*/quick-reference/bzr-quick-reference.svg) \
-       $(wildcard doc/*/quick-reference/bzr-quick-reference.png) \
-       $(wildcard doc/*/quick-reference/bzr-quick-reference.pdf) \
+       $(wildcard doc/*/bzr-en-quick-reference.svg) \
+       $(wildcard doc/*/bzr-en-quick-reference.png) \
+       $(wildcard doc/*/bzr-en-quick-reference.pdf) \
+       $(wildcard doc/*/bzr-es-quick-reference.svg) \
+       $(wildcard doc/*/bzr-es-quick-reference.png) \
+       $(wildcard doc/*/bzr-es-quick-reference.pdf) \
+       $(wildcard doc/*/bzr-ru-quick-reference.svg) \
+       $(wildcard doc/*/bzr-ru-quick-reference.png) \
+       $(wildcard doc/*/bzr-ru-quick-reference.pdf) \
        $(wildcard doc/*/user-guide/images/*.png)
-htm_files := $(patsubst %.txt, %.html, $(txt_files)) 
 
 # doc/developers/*.txt files that should *not* be individually
 # converted to HTML
@@ -120,15 +237,21 @@
 	doc/developers/diff.txt \
 	doc/developers/directory-fingerprints.txt \
 	doc/developers/gc.txt \
+	doc/developers/implementation-notes.txt \
 	doc/developers/incremental-push-pull.txt \
+	doc/developers/index.txt \
 	doc/developers/initial-push-pull.txt \
 	doc/developers/merge-scaling.txt \
+	doc/developers/miscellaneous-notes.txt \
 	doc/developers/missing.txt \
 	doc/developers/performance-roadmap-rationale.txt \
 	doc/developers/performance-use-case-analysis.txt \
 	doc/developers/planned-change-integration.txt \
 	doc/developers/planned-performance-changes.txt \
+	doc/developers/plans.txt \
+	doc/developers/process.txt \
 	doc/developers/revert.txt \
+	doc/developers/specifications.txt \
 	doc/developers/status.txt \
 	doc/developers/uncommit.txt
 
@@ -136,30 +259,15 @@
 dev_txt_files := $(filter-out $(dev_txt_nohtml), $(dev_txt_all))
 dev_htm_files := $(patsubst %.txt, %.html, $(dev_txt_files)) 
 
-doc/%/user-guide/index.html: $(wildcard $(addsuffix /*.txt, doc/%/user-guide)) 
-	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
-
-# Set the paper size for PDF files.
-# Options:  'a4' (ISO A4 size), 'letter' (US Letter size)
-PAPERSIZE = a4
-# TODO: Add generation for Russian PDF
-PDF_DOCS := doc/en/user-guide/user-guide.$(PAPERSIZE).pdf
-
-# Copy and modify the RST sources, and convert SVG images to PDF
-# files for use a images in the LaTeX-generated PDF.
-# Then generate the PDF output from the modified RST sources.
-doc/en/user-guide/user-guide.$(PAPERSIZE).pdf: $(wildcard $(addsuffix /*.txt, doc/en/user-guide))
-	mkdir -p doc/en/user-guide/latex_prepared
-	$(PYTHON) tools/prepare_for_latex.py \
-	    --out-dir=doc/en/user-guide/latex_prepared \
-	    --in-dir=doc/en/user-guide
-	cd doc/en/user-guide/latex_prepared && \
-	    $(PYTHON) ../../../../tools/rst2pdf.py \
-	        --documentoptions=10pt,$(PAPERSIZE)paper \
-	        --input-encoding=UTF-8:strict --output-encoding=UTF-8:strict \
-	        --strict --title="Bazaar User Guide" \
-	        index.txt ../user-guide.$(PAPERSIZE).pdf
-
+doc/en/user-guide/index-plain.html: $(wildcard $(addsuffix /*.txt, doc/en/user-guide)) 
+	$(rst2html) --stylesheet=../../default.css $(dir $@)index-plain.txt $@
+
+#doc/es/user-guide/index.html: $(wildcard $(addsuffix /*.txt, doc/es/user-guide)) 
+#	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
+#
+#doc/ru/user-guide/index.html: $(wildcard $(addsuffix /*.txt, doc/ru/user-guide)) 
+#	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
+#
 doc/developers/%.html: doc/developers/%.txt
 	$(rst2html) --stylesheet=../default.css $< $@
 
@@ -172,55 +280,42 @@
 %.html: %.txt
 	$(rst2html) --stylesheet=../../default.css $< $@
 
-MAN_DEPENDENCIES = bzrlib/builtins.py \
-	$(wildcard bzrlib/*.py) \
-	$(wildcard bzrlib/*/*.py) \
-	tools/generate_docs.py \
-	$(wildcard $(addsuffix /*.txt, bzrlib/help_topics/en)) 
-
 doc/en/user-reference/bzr_man.txt: $(MAN_DEPENDENCIES)
 	$(PYTHON) tools/generate_docs.py -o $@ rstx
 
 doc/en/release-notes/NEWS.txt: NEWS
 	$(PYTHON) -c "import shutil; shutil.copyfile('$<', '$@')"
 
-MAN_PAGES = man1/bzr.1
-man1/bzr.1: $(MAN_DEPENDENCIES)
-	$(PYTHON) tools/generate_docs.py -o $@ man
-
 upgrade_guide_dependencies =  $(wildcard $(addsuffix /*.txt, doc/en/upgrade-guide)) 
 
 doc/en/upgrade-guide/index.html: $(upgrade_guide_dependencies)
 	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
 
-# build a png of our performance task list
-# 
-# this is no longer built by default; you can build it if you want to look at it
-doc/developers/performance.png: doc/developers/performance.dot
-	@echo Generating $@
-	@dot -Tpng $< -o$@ || echo "Dot not installed; skipping generation of $@"
-
 derived_web_docs = $(htm_files) $(dev_htm_files) 
 WEB_DOCS = $(derived_web_docs) $(non_txt_files)
 ALL_DOCS = $(derived_web_docs) $(MAN_PAGES)
 
 # the main target to build all the docs
-docs: $(ALL_DOCS)
+docs-plain: $(ALL_DOCS)
 
 # produce a tree containing just the final docs, ready for uploading to the web
 HTMLDIR := html_docs
-html-docs: docs
+html-plain: docs-plain
 	$(PYTHON) tools/win32/ostools.py copytree $(WEB_DOCS) $(HTMLDIR)
 
-# Produce PDF documents.  Requires pdfLaTeX, rubber, and Inkscape.
-pdf-docs: $(PDF_DOCS)
-
 # clean produced docs
-clean-docs:
+clean-plain:
 	$(PYTHON) tools/win32/ostools.py remove $(ALL_DOCS) \
 	    $(HTMLDIR) $(derived_txt_files)
-	rm -f doc/*/user-guide/*.pdf
-	rm -rf doc/*/user-guide/latex_prepared
+
+
+### Miscellaneous Documentation Targets ###
+
+# build a png of our performance task list
+# this is no longer built by default; you can build it if you want to look at it
+doc/developers/performance.png: doc/developers/performance.dot
+	@echo Generating $@
+	@dot -Tpng $< -o$@ || echo "Dot not installed; skipping generation of $@"
 
 
 ### Windows Support ###
@@ -296,6 +391,9 @@
 	$(PYTHON) tools/win32/ostools.py remove bzr-*win32.exe
 	$(PYTHON) tools/win32/ostools.py remove dist
 
+
+### Packaging Targets ###
+
 .PHONY: dist dist-upload-escudero check-dist-tarball
 
 # build a distribution tarball and zip file.

=== modified file 'NEWS'
--- NEWS	2009-09-14 01:48:28 +0000
+++ NEWS	2009-09-15 02:57:23 +0000
@@ -120,8 +120,10 @@
   parameterisation, and is substantially faster. (Robert Collins)
 
 
-bzr 2.0rc2 (not released yet)
-#############################
+bzr 2.0rc2
+##########
+
+:2.0rc2: 2009-09-10
 
 New Features
 ************
@@ -200,6 +202,14 @@
 * Help on hooks no longer says 'Not deprecated' for hooks that are
   currently supported. (Ian Clatworthy, #422415)
 
+* PDF and CHM (Windows HtmlHelp) formats are now supported for the
+  user documentation. The HTML documentation is better broken up into
+  topics. (Ian Clatworthy)
+
+* The developer and foreign language documents are now separated
+  out so that searching in the HTML and CHM files produces more
+  useful results. (Ian Clatworthy)
+
 * The main table of contents now provides links to the new Migration Docs
   and Plugins Guide. (Ian Clatworthy)
 
@@ -207,7 +217,6 @@
 bzr 2.0rc1
 ##########
 
-
 :Codename: no worries
 :2.0rc1: 2009-08-26
 
@@ -216,9 +225,8 @@
 fixes and stabilization, covering both 2a and previous formats.
 
 The Bazaar team decided that 2.0 will be a long-term supported
-release, with bugfix-only releases based on it continuing for at
-least six months or until the following stable release (we said
-that previously, but that's worth repeating).
+release, with bugfix-only releases based on it, continuing for at
+least six months or until the following stable release.
 
 Compatibility Breaks
 ********************
@@ -226,7 +234,7 @@
 * The default format for bzr is now ``2a``. This format brings many
   significant performance and size improvements. bzr can pull from
   any existing repository into a ``2a`` one, but can only transfer
-  into ``rich-root`` repositories from ``2a``. The Upgrade guide
+  from ``2a`` into ``rich-root`` repositories. The Upgrade guide
   has more information about this change. (Robert Collins)
 
 * On Windows auto-detection of Putty's plink.exe is disabled.
@@ -318,8 +326,17 @@
 Testing
 *******
 
-bzr 1.18.1 NOT RELEASED YET
-###########################
+bzr 1.18.1
+##########
+
+:Codename:     nein nein nein!
+:1.18.1:       2009-09-09
+
+This release fixes two small but worthwhile bugs relevant to users on
+Microsoft Windows: some commands that failed on with locking errors will
+now work, and a bug that caused poor performance after committing a file
+with line-ending conversion has now been fixed.  It also fixes a bug in
+pushing to older servers.
 
 Bug Fixes
 *********
@@ -328,13 +345,17 @@
   conversion will commit too many copies a file.
   (Martin Pool, #415508)
 
+* Fix assertion error about ``_remember_remote_is_before`` in
+  ``set_tags_bytes`` when pushing to older smart servers.  
+  (Andrew Bennetts, Alexander Belchenko, #418931)
+
 Improvements
 ************
 
-* ``bzr push`` locally on windows will no longer give a locking error with
+* ``bzr push`` locally on Windows will no longer give a locking error with
   dirstate based formats. (Robert Collins)
 
-* ``bzr shelve`` and ``bzr unshelve`` now work on windows.
+* ``bzr shelve`` and ``bzr unshelve`` now work on Windows.
   (Robert Collins, #305006)
 
 API Changes
@@ -699,8 +720,8 @@
   knit format repositories.  (Andrew Bennetts, #405653)
   
 
-bzr 1.17 "So late it's brunch" 2009-07-20
-#########################################
+bzr 1.17
+########
 :Codename: so-late-its-brunch
 :1.17rc1: 2009-07-13
 :1.17: 2009-07-20
@@ -949,8 +970,10 @@
   this class and the UI.  (Martin Pool)
 
 
-bzr 1.16.1 2009-06-26
-#####################
+bzr 1.16.1
+##########
+
+:Released: 2009-06-26
 
 End user testing of the 2a format revealed two serious bugs. The first,
 #365615, caused bzr to raise AbsentContentFactory errors when autopacking.
@@ -1005,8 +1028,8 @@
   (Robert Collins, #376748)
 
 
-bzr 1.16 "It's yesterday in California" 2009-06-18
-##################################################
+bzr 1.16
+########
 :Codename: yesterday-in-california
 :1.16rc1: 2009-06-11
 :1.16: 2009-06-18
@@ -2483,8 +2506,11 @@
   (Vincent Ladeuil)
 
 
-bzr 1.11 "Eyes up!" 2009-01-19
-##############################
+bzr 1.11
+########
+
+:Codename: "Eyes up!"
+:Released: 2009-01-19
 
 This first monthly release of Bazaar for 2009 improves Bazaar's operation
 in Windows, Mac OS X, and other situations where file names are matched
@@ -2510,8 +2536,11 @@
 
 
 
-bzr 1.11rc1 "Eyes up!" 2009-01-09
-#################################
+bzr 1.11rc1
+###########
+
+:Codename: "Eyes up!"
+:Released: 2009-01-09
 
 Changes
 *******
@@ -2747,8 +2776,10 @@
 
 
 
-bzr 1.10 2008-12-05
-###################
+bzr 1.10
+########
+
+:Released: 2008-12-05
 
 Bazaar 1.10 has several performance improvements for copying revisions
 (especially for small updates to large projects).  There has also been a
@@ -2773,8 +2804,10 @@
   topologically. (John Arbash Meinel, #304841)
 
 
-bzr 1.10rc1 2008-11-28
-######################
+bzr 1.10rc1
+###########
+
+:Released: 2008-11-28
 
 This release of Bazaar focuses on performance improvements when pushing
 and pulling revisions, both locally and to remote networks.  The popular
@@ -2894,8 +2927,10 @@
 * Doctests now only report the first failure.  (Martin Pool)
 
 
-bzr 1.9 2008-11-07
-##################
+bzr 1.9
+#######
+
+:Released: 2008-11-07
 
 This release of Bazaar adds a new repository format, ``1.9``, with smaller
 and more efficient index files.  This format can be specified when
@@ -2917,8 +2952,10 @@
   (John Arbash Meinel, #293746)
 
 
-bzr 1.9rc1 2008-10-31
-#####################
+bzr 1.9rc1
+##########
+
+:Released: 2008-10-31
 
 New Features
 ************
@@ -3035,8 +3072,10 @@
   configuration of authetication credentials.
 
 
-bzr 1.8 2008-10-16
-##################
+bzr 1.8
+#######
+
+:Released: 2008-10-16
 
 Bazaar 1.8 includes several fixes that improve working tree performance,
 display of revision logs, and merges.  The bzr testsuite now passes on OS
@@ -3057,8 +3096,10 @@
   that platform.  (Alexander Belchenko, Martin Pool, #277481)
 
 
-bzr 1.8rc1 2008-10-07
-#####################
+bzr 1.8rc1
+##########
+
+:Released: 2008-10-07
 
 Changes
 *******
@@ -3256,14 +3297,18 @@
   (Vincent Ladeuil)
 
 
-bzr 1.7.1 2008-10-01
-####################
+bzr 1.7.1
+#########
+
+:Released:  2008-10-01
 
 No changes from 1.7.1rc1.
 
 
-bzr 1.7.1rc1 2008-09-24
-#######################
+bzr 1.7.1rc1
+############
+
+:Released: 2008-09-24
 
 This release just includes an update to how the merge algorithm handles
 file paths when we encounter complex history.
@@ -3278,8 +3323,10 @@
   (John Arbash Meinel)
 
 
-bzr 1.7 2008-09-23
-##################
+bzr 1.7
+#######
+
+:Released: 2008-09-23
 
 This release includes many bug fixes and a few performance and feature
 improvements.  ``bzr rm`` will now scan for missing files and remove them,
@@ -3296,8 +3343,10 @@
   packaging qbzr. (Mark Hammond)
 
 
-bzr 1.7rc2 2008-09-17
-#####################
+bzr 1.7rc2
+##########
+
+:Released: 2008-09-17
 
 A few bug fixes from 1.7rc1. The biggest change is a new
 ``RemoteBranch.get_stacked_on_url`` rpc. This allows clients that are
@@ -3321,8 +3370,10 @@
   (Andrew Bennetts)
 
 
-bzr 1.7rc1 2008-09-09
-#####################
+bzr 1.7rc1
+##########
+
+:Released: 2008-09-09
 
 This release candidate for bzr 1.7 has several bug fixes and a few
 performance and feature improvements.  ``bzr rm`` will now scan for
@@ -3519,16 +3570,20 @@
   clients now use this mechanism.  (Neil Martinsen-Burrell)
 
 
-bzr 1.6.1 2008-09-05
-####################
+bzr 1.6.1
+#########
+
+:Released: 2008-09-05
 
 A couple regressions were found in the 1.6 release. There was a
 performance issue when using ``bzr+ssh`` to branch large repositories,
 and some problems with stacking and ``rich-root`` capable repositories.
 
 
-bzr 1.6.1rc2 2008-09-03
-#######################
+bzr 1.6.1rc2
+############
+
+:Released: 2008-09-03
 
 Bug Fixes
 *********
@@ -3539,8 +3594,10 @@
   (John Arbash Meinel, #264321)
 
 
-bzr 1.6.1rc1 2008-08-29
-#######################
+bzr 1.6.1rc1
+############
+
+:Released: 2008-08-29
 
 This release fixes a few regressions found in the 1.6 client. Fetching
 changes was using an O(N^2) buffering algorithm, so for large projects it
@@ -3580,8 +3637,10 @@
   (John Arbash Meinel, #262333)
 
 
-bzr 1.6 2008-08-25
-##################
+bzr 1.6
+#######
+
+:Released: 2008-08-25
 
 Finally, the long awaited bzr 1.6 has been released. This release includes
 new features like Stacked Branches, improved weave merge, and an updated
@@ -3594,8 +3653,10 @@
 TortoiseBzr in the standalone Windows installer.
 
 
-bzr 1.6rc5 2008-08-19
-#####################
+bzr 1.6rc5
+##########
+
+:Released: 2008-08-19
 
 Bug Fixes
 *********
@@ -3607,8 +3668,10 @@
   (This change was reverted when merged to bzr.dev)
 
 
-bzr 1.6rc4 2008-08-18
-#####################
+bzr 1.6rc4
+##########
+
+:Released: 2008-08-18
 
 Bug Fixes
 *********
@@ -3618,8 +3681,10 @@
   rather than preserving deltas.  (John Arbash Meinel, #256757)
 
 
-bzr 1.6rc3 2008-08-14
-#####################
+bzr 1.6rc3
+##########
+
+:Released: 2008-08-14
 
 Changes
 *******
@@ -3652,8 +3717,10 @@
   development which is substantially faster. (Robert Collins)
 
 
-bzr 1.6rc2 2008-08-13
-#####################
+bzr 1.6rc2
+##########
+
+:Released: 2008-08-13
 
 This release candidate has a few minor bug fixes, and some regression
 fixes for Windows.
@@ -3691,8 +3758,10 @@
   will get the same results.  (John Arbash Meinel, #232188)
 
 
-bzr 1.6rc1 2008-08-06
-#####################
+bzr 1.6rc1
+##########
+
+:Released: 2008-08-06
 
 This release candidate for bzr 1.6 solidifies the new branch stacking
 feature.  Bazaar now recommends that users upgrade all knit repositories,
@@ -3828,8 +3897,10 @@
   (Ian Clatworthy)
 
 
-bzr 1.6beta3 2008-07-17
-#######################
+bzr 1.6beta3
+############
+
+:Released: 2008-07-17
 
 This release adds a new 'stacked branches' feature allowing branches to
 share storage without being in the same repository or on the same machine.
@@ -4001,8 +4072,10 @@
   (Robert Collins)
 
 
-bzr 1.6beta2 2008-06-10
-#######################
+bzr 1.6beta2
+############
+
+:Released: 2008-06-10
 
 This release contains further progress towards our 1.6 goals of shallow
 repositories, and contains a fix for some user-affecting bugs in the
@@ -4085,9 +4158,10 @@
 * Knit record serialisation is now stricter on what it will accept, to
   guard against potential internal bugs, or broken input. (Robert Collins)
 
-bzr 1.6beta1 2008-06-02
-#######################
+bzr 1.6beta1
+############
 
+:Released: 2008-06-02
 
 Commands that work on the revision history such as push, pull, missing,
 uncommit and log are now substantially faster.  This release adds a
@@ -4305,8 +4379,10 @@
   (Martin Pool)
 
 
-bzr 1.5 2008-05-16
-##################
+bzr 1.5
+#######
+
+:Released: 2008-05-16
 
 This release of Bazaar includes several updates to the documentation, and fixes
 to prepare for making rich root support the default format. Many bugs have been
@@ -4327,8 +4403,10 @@
   (Ian Clatworthy)
 
 
-bzr 1.5rc1 2008-05-09
-#####################
+bzr 1.5rc1
+##########
+
+:Released: 2008-05-09
 
 Changes
 *******
@@ -4498,8 +4576,10 @@
   (Martin Pool)
 
 
-bzr 1.4 2008-04-28
-##################
+bzr 1.4 
+#######
+
+:Released: 2008-04-28
 
 This release of Bazaar includes handy improvements to the speed of log and
 status, new options for several commands, improved documentation, and better
@@ -4518,8 +4598,10 @@
   (John Arbash Meinel, Andrew Bennetts, #214894)
 
 
-bzr 1.4rc2 2008-04-21
-#####################
+bzr 1.4rc2
+##########
+
+:Released: 2008-04-21
 
 Bug Fixes
 *********
@@ -4542,8 +4624,10 @@
   (Robert Collins, John Arbash Meinel)
 
 
-bzr 1.4rc1 2008-04-11
-#####################
+bzr 1.4rc1
+##########
+
+:Released: 2008-04-11
 
 Changes
 *******
@@ -4830,14 +4914,18 @@
   ``Graph.get_parent_map`` returns a dict of key:parents. (Robert Collins)
 
 
-bzr 1.3.1 2008-04-09
-####################
+bzr 1.3.1
+#########
+
+:Released: 2008-04-09
 
 No changes from 1.3.1rc1.
 
 
-bzr 1.3.1rc1 2008-04-04
-#######################
+bzr 1.3.1rc1
+############
+
+:Released: 2008-04-04
 
 Bug Fixes
 *********
@@ -4848,8 +4936,10 @@
   (#208418, Andrew Bennetts, Martin Pool, Robert Collins)
 
 
-bzr 1.3 2008-03-20
-##################
+bzr 1.3
+#######
+
+:Released: 2008-03-20
 
 Bazaar has become part of the GNU project <http://www.gnu.org>
 
@@ -4865,8 +4955,10 @@
   (#202778, Martin Pool)
 
 
-bzr 1.3rc1 2008-03-16
-#####################
+bzr 1.3rc1
+##########
+
+:Released: 2008-03-16
 
 Notes When Upgrading
 ********************
@@ -5052,8 +5144,10 @@
   format. (Robert Collins)
 
 
-bzr 1.2 2008-02-15
-##################
+bzr 1.2
+#######
+
+:Released: 2008-02-15
 
 Bug Fixes
 *********
@@ -5061,8 +5155,10 @@
 * Fix failing test in Launchpad plugin. (Martin Pool)
 
 
-bzr 1.2rc1 2008-02-13
-#####################
+bzr 1.2rc1
+##########
+
+:Released: 2008-02-13
 
 Notes When Upgrading
 ********************
@@ -5263,13 +5359,17 @@
   revision names etc. (Robert Collins)
 
 
-bzr 1.1 2008-01-15
-##################
+bzr 1.1
+#######
+
+:Released: 2008-01-15
 
 (no changes from 1.1rc1)
 
-bzr 1.1rc1 2008-01-05
-#####################
+bzr 1.1rc1
+##########
+
+:Released: 2008-01-05
 
 Changes
 *******
@@ -5479,8 +5579,10 @@
   replaced by the new helper methods added in this release. (Robert Collins)
 
 
-bzr 1.0 2007-12-14
-##################
+bzr 1.0
+#######
+
+:Released: 2007-12-14
 
 Documentation
 *************
@@ -5497,8 +5599,10 @@
   (Ian Clatworthy)
 
 
-bzr 1.0rc3 2007-12-11
-#####################
+bzr 1.0rc3
+##########
+
+:Released: 2007-12-11
 
 Changes
 *******
@@ -5539,8 +5643,10 @@
   (Vincent Ladeuil)
 
 
-bzr 1.0rc2 2007-12-07
-#####################
+bzr 1.0rc2
+##########
+
+:Released: 2007-12-07
 
 Improvements
 ************
@@ -5614,8 +5720,10 @@
   ``started`` methods. (Matt Nordhoff)
 
 
-bzr 1.0rc1 2007-11-30
-#####################
+bzr 1.0rc1
+##########
+
+:Released: 2007-11-30
 
 Notes When Upgrading
 ********************
@@ -5891,8 +5999,10 @@
 * InventoryEntry.diff is now deprecated.  Please use diff.DiffTree instead.
 
 
-bzr 0.92 2007-11-05
-###################
+bzr 0.92
+########
+
+:Released: 2007-11-05
 
 Changes
 *******
@@ -5900,8 +6010,10 @@
   * New uninstaller on Win32.  (Alexander Belchenko)
 
 
-bzr 0.92rc1 2007-10-29
-######################
+bzr 0.92rc1
+###########
+
+:Released: 2007-10-29
 
 Changes
 *******
@@ -6220,8 +6332,10 @@
   raises a Python warning.  (Martin Pool)
 
 
-bzr 0.91 2007-09-26
-###################
+bzr 0.91
+########
+
+:Released: 2007-09-26
 
 Bug Fixes
 *********
@@ -6242,15 +6356,19 @@
   (Andrew Bennetts)
 
 
-bzr 0.91rc2 2007-09-11
-######################
+bzr 0.91rc2
+###########
+
+:Released: 2007-09-11
 
 * Replaced incorrect tarball for previous release; a debug statement was left
   in bzrlib/remote.py.
 
 
-bzr 0.91rc1 2007-09-11
-######################
+bzr 0.91rc1
+###########
+
+:Released: 2007-09-11
 
 Changes
 *******
@@ -6577,8 +6695,10 @@
   [] to revert all files is deprecated.  (Aaron Bentley)
 
 
-bzr 0.90 2007-08-28
-###################
+bzr 0.90
+########
+
+:Released: 2007-08-28
 
 Improvements
 ************
@@ -6601,8 +6721,10 @@
   and call ``create_repository`` on that.  (Martin Pool)
 
 
-bzr 0.90rc1 2007-08-14
-######################
+bzr 0.90rc1
+###########
+
+:Released: 2007-08-14
 
 Bugfixes
 ********
@@ -6874,8 +6996,10 @@
   parameter.  Varargs-style parameters are deprecated. (Aaron Bentley)
 
 
-bzr 0.18  2007-07-17
-####################
+bzr 0.18
+########
+
+:Released:  2007-07-17
 
 Bugfixes
 ********
@@ -6883,8 +7007,10 @@
 * Fix 'bzr add' crash under Win32 (Kuno Meyer)
 
 
-bzr 0.18rc1  2007-07-10
-#######################
+bzr 0.18rc1
+###########
+
+:Released:  2007-07-10
 
 Bugfixes
 ********
@@ -7135,8 +7261,10 @@
   (Vincent Ladeuil, #110448)
 
 
-bzr 0.17  2007-06-18
-####################
+bzr 0.17
+########
+
+:Released:  2007-06-18
 
 Bugfixes
 ********
@@ -7148,8 +7276,10 @@
   (Aaron Bentley, Ian Clatworthy, #120930)
 
 
-bzr 0.17rc1  2007-06-12
-#######################
+bzr 0.17rc1
+###########
+
+:Released:  2007-06-12
 
 Notes When Upgrading
 ********************
@@ -7250,8 +7380,10 @@
   your repository. (Previously Branch6 only supported revisions in your
   mainline). (John Arbash Meinel, #115343)
 
-bzr 0.16  2007-05-07
-####################
+bzr 0.16
+########
+
+:Released:  2007-05-07
 
 Bugfixes
 ********
@@ -7281,8 +7413,10 @@
   diff`` and ``bzr status`` significantly improving the speed of
   both. (John Arbash Meinel)
 
-bzr 0.16rc2  2007-04-30
-#######################
+bzr 0.16rc2
+###########
+
+:Released:  2007-04-30
 
 Bugfixes
 ********
@@ -7305,8 +7439,10 @@
 * ``WorkingTree4._iter_changes`` should not descend into unversioned
   directories. (John Arbash Meinel, #110399)
 
-bzr 0.16rc1  2007-04-26
-#######################
+bzr 0.16rc1
+###########
+
+:Released:  2007-04-26
 
 Notes When Upgrading
 ********************
@@ -7613,8 +7749,10 @@
   implementation of new auth schemes for both http and proxy.
   (Vincent Ladeuil)
 
-bzr 0.15 2007-04-01
-###################
+bzr 0.15
+########
+
+:Released: 2007-04-01
 
 Bugfixes
 ********
@@ -7626,8 +7764,10 @@
   checking out a branch that contains an old-format working tree.
   (Martin Pool)
 
-bzr 0.15rc3  2007-03-26
-#######################
+bzr 0.15rc3
+###########
+
+:Released:  2007-03-26
 
 Changes
 *******
@@ -7702,8 +7842,10 @@
 * Correctly handles mutiple permanent http redirections.
   (vila, #88780)
 
-bzr 0.15rc2  2007-03-14
-#######################
+bzr 0.15rc2
+###########
+
+:Released:  2007-03-14
 
 Notes When Upgrading
 ********************
@@ -7756,8 +7898,10 @@
   (Wouter van Heyst, #53483)
 
 
-bzr 0.15rc1  2007-03-07
-#######################
+bzr 0.15rc1
+###########
+
+:Released:  2007-03-07
 
 Surprises
 *********
@@ -7987,8 +8131,10 @@
   before the rest of the suite.  (Martin Pool)
 
 
-bzr 0.14  2007-01-23
-####################
+bzr 0.14
+########
+
+:Released:  2007-01-23
 
 Improvements
 ************
@@ -8007,8 +8153,10 @@
   it is in is below a repository. (James Westby, #77306)
 
 
-bzr 0.14rc1  2007-01-16
-#######################
+bzr 0.14rc1
+###########
+
+:Released:  2007-01-16
 
 Improvements
 ************
@@ -8142,14 +8290,18 @@
   (Alexander Belchenko, #68124)
 
 
-bzr 0.13  2006-12-05
-####################
+bzr 0.13
+########
+
+:Released:  2006-12-05
 
 No changes from 0.13rc
 
 
-bzr 0.13rc1  2006-11-27
-#######################
+bzr 0.13rc1
+###########
+
+:Released:  2006-11-27
 
 Improvements
 ************
@@ -8274,8 +8426,10 @@
 * TestingHTTPRequestHandler really handles the Range header
   (previously it was ignoring it and returning the whole file,).
 
-bzr 0.12  2006-10-30
-####################
+bzr 0.12
+########
+
+:Released:  2006-10-30
 
 Internals
 *********
@@ -8284,8 +8438,10 @@
   and remove benchmarks that take longer than 10min to run.
   (John Arbash Meinel)
 
-bzr 0.12rc1  2006-10-23
-#######################
+bzr 0.12rc1
+###########
+
+:Released:  2006-10-23
 
 Improvements
 ************
@@ -8406,13 +8562,17 @@
   option to set the BzrDir, Repository and Branch formats of the
   created objects. (Robert Collins, John Arbash Meinel)
 
-bzr 0.11  2006-10-02
-####################
+bzr 0.11
+########
+
+:Released:  2006-10-02
 
 * Smart server transport test failures on windows fixed. (Lukáš Lalinský).
 
-bzr 0.11rc2  2006-09-27
-#######################
+bzr 0.11rc2
+###########
+
+:Released:  2006-09-27
 
 Bug Fixes
 *********
@@ -8422,8 +8582,10 @@
 * Commit performance regression fixed. (Aaron Bentley, Robert Collins, John
   Arbash Meinel).
 
-bzr 0.11rc1  2006-09-25
-#######################
+bzr 0.11rc1
+###########
+
+:Released:  2006-09-25
 
 Improvements
 ************
@@ -8616,8 +8778,10 @@
   allow upgrades to a richer interface than the VFS one provided by
   Transport. (Andrew Bennetts, Martin Pool)
 
-bzr 0.10  2006-08-29
-####################
+bzr 0.10
+########
+
+:Released:  2006-08-29
 
 Improvements
 ************
@@ -8694,8 +8858,10 @@
   need to be installed. This should help make the life of packagers
   easier. (John Arbash Meinel)
 
-bzr 0.9.0  2006-08-11
-#####################
+bzr 0.9.0
+#########
+
+:Released:  2006-08-11
 
 Surprises
 *********
@@ -8962,16 +9128,20 @@
 
 * "RevisionTree" is now in bzrlib/revisiontree.py. (Robert Collins)
 
-bzr 0.8.2  2006-05-17
-#####################
+bzr 0.8.2
+#########
+
+:Released:  2006-05-17
 
 Bug Fixes
 *********
 
 * setup.py failed to install launchpad plugin.  (Martin Pool)
 
-bzr 0.8.1  2006-05-16
-#####################
+bzr 0.8.1
+#########
+
+:Released:  2006-05-16
 
 Bug Fixes
 *********
@@ -9024,8 +9194,10 @@
 * Fix test case for bzr info in upgrading a standalone branch to metadir,
   uses bzrlib api now. (Olaf Conradi)
 
-bzr 0.8  2006-05-08
-###################
+bzr 0.8
+#######
+
+:Released:  2006-05-08
 
 Notes When Upgrading
 ********************
@@ -9286,8 +9458,10 @@
 * ``run_bzr`` and ``run_bzr_captured`` now accept a 'stdin="foo"'
   parameter which will provide String("foo") to the command as its stdin.
 
-bzr 0.7 2006-01-09
-##################
+bzr 0.7
+#######
+
+:Released: 2006-01-09
 
 Changes
 *******
@@ -9582,8 +9756,10 @@
 * ``bzrlib.osutils.safe_unicode`` now exists to provide parameter coercion
   for functions that need unicode strings. (Robert Collins)
 
-bzr 0.6 2005-10-28
-##################
+bzr 0.6
+#######
+
+:Released: 2005-10-28
 
 Improvements
 ************
@@ -9798,8 +9974,10 @@
   [-1] in the revision-history. (Andres Salomon)
 
 
-bzr 0.1.1 2005-10-12
-####################
+bzr 0.1.1
+#########
+
+:Released: 2005-10-12
 
 Bug Fixes
 *********
@@ -9816,8 +9994,10 @@
 * Avoid some unnecessary http operations in branch and pull.
 
 
-bzr 0.1 2005-10-11
-##################
+bzr 0.1
+#######
+
+:Released: 2005-10-11
 
 Notes
 *****
@@ -9946,8 +10126,10 @@
   of tests to run, e.g. ``bzr selftest test_weave``
 
 
-bzr 0.0.9 2005-09-23
-####################
+bzr 0.0.9
+#########
+
+:Released: 2005-09-23
 
 Bug Fixes
 *********
@@ -9988,8 +10170,11 @@
   another (used by pull, merged, etc.)
 
 
-bzr 0.0.8 2005-09-20
-####################
+bzr 0.0.8
+#########
+
+:Released: 2005-09-20
+
 
 Improvements
 ************
@@ -10039,8 +10224,10 @@
 * Quieten warnings about locking; patch from Matt Lavin.
 
 
-bzr-0.0.7 2005-09-02
-####################
+bzr-0.0.7
+#########
+
+:Released: 2005-09-02
 
 New Features
 ************
@@ -10094,8 +10281,10 @@
 
 
 
-bzr-0.0.6 2005-08-18
-####################
+bzr-0.0.6
+#########
+
+:Released: 2005-08-18
 
 New Features
 ************
@@ -10180,8 +10369,10 @@
 * Fix bugs in committing only selected files or within a subdirectory.
 
 
-bzr-0.0.5  2005-06-15
-#####################
+bzr-0.0.5
+#########
+
+:Released:  2005-06-15
 
 Changes
 *******
@@ -10322,8 +10513,10 @@
   2.4 is now only recommended.
 
 
-bzr-0.0.4  2005-04-22
-#####################
+bzr-0.0.4
+#########
+
+:Released:  2005-04-22
 
 Enhancements
 ************
@@ -10391,8 +10584,10 @@
   from QuantumG.
 
 
-bzr-0.0.3  2005-04-06
-#####################
+bzr-0.0.3
+#########
+
+:Released:  2005-04-06
 
 Enhancements
 ************
@@ -10446,8 +10641,11 @@
 * Win32 fixes from Steve Brown.
 
 
-bzr-0.0.2  "black cube"  2005-03-31
-###################################
+bzr-0.0.2
+#########
+
+:Codename: "black cube"
+:Released: 2005-03-31
 
 Enhancements
 ************
@@ -10475,8 +10673,10 @@
   the root directory only.
 
 
-bzr-0.0.1  2005-03-26
-#####################
+bzr-0.0.1
+#########
+
+:Released:  2005-03-26
 
 Enhancements
 ************
@@ -10505,8 +10705,10 @@
   supported).
 
 
-bzr-0.0.0.69  2005-03-22
-########################
+bzr-0.0.0.69
+############
+
+:Released:  2005-03-22
 
 Enhancements
 ************

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2009-09-08 16:45:11 +0000
+++ bzrlib/builtins.py	2009-09-15 01:52:34 +0000
@@ -1673,7 +1673,7 @@
                 lazy_registry=('bzrlib.bzrdir', 'format_registry'),
                 converter=lambda name: bzrdir.format_registry.make_bzrdir(name),
                 value_switches=True,
-                title="Branch Format",
+                title="Branch format",
                 ),
          Option('append-revisions-only',
                 help='Never change revnos or the existing log.'

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2009-09-14 01:48:28 +0000
+++ bzrlib/commands.py	2009-09-15 02:57:23 +0000
@@ -457,6 +457,13 @@
         # so we get <https://bugs.launchpad.net/bzr/+bug/249908>.  -- mbp
         # 20090319
         options = option.get_optparser(self.options()).format_option_help()
+        # XXX: According to the spec, ReST option lists actually don't support 
+        # options like --1.9 so that causes syntax errors (in Sphinx at least).
+        # As that pattern always appears in the commands that break, we trap
+        # on that and then format that block of 'format' options as a literal
+        # block.
+        if not plain and options.find('  --1.9  ') != -1:
+            options = options.replace(' format:\n', ' format::\n\n', 1)
         if options.startswith('Options:'):
             result += ':' + options
         elif options.startswith('options:'):

=== modified file 'bzrlib/doc_generate/autodoc_rstx.py'
--- bzrlib/doc_generate/autodoc_rstx.py	2009-07-22 14:36:38 +0000
+++ bzrlib/doc_generate/autodoc_rstx.py	2009-09-09 14:35:26 +0000
@@ -31,6 +31,14 @@
 import bzrlib.osutils
 
 
+# Set this to True to generate a file per topic.
+# This probably ought to be an option. The files probably
+# ought to be prefixed with their section name as well so
+# there's zero risk of clashing with a standard sphinx
+# topic (like search.html).
+FILE_PER_TOPIC = False
+
+
 def get_filename(options):
     """Provides name of manual"""
     return "%s_man.txt" % (options.bzr_name)
@@ -119,6 +127,8 @@
 
 def _dump_text(filename, text):
     """Dump text to filename."""
+    if not FILE_PER_TOPIC:
+        return
     f =  open(filename, "w")
     f.writelines(text)
     f.close()
@@ -160,13 +170,6 @@
 Bazaar User Reference
 #####################
 
-:Version:   %(version)s
-:Generated: %(datestamp)s
-
-.. contents:: :depth: 3
-
------
-
 About This Manual
 #################
 

=== added file 'bzrlib/doc_generate/sphinx_conf.py'
--- bzrlib/doc_generate/sphinx_conf.py	1970-01-01 00:00:00 +0000
+++ bzrlib/doc_generate/sphinx_conf.py	2009-09-08 16:37:05 +0000
@@ -0,0 +1,214 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# All configuration values have a default; values that are commented out
+# serve to show the default.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+#sys.path.append(os.path.abspath('.'))
+
+
+# -- General configuration -----------------------------------------------------
+
+# Add any Sphinx extension module names here, as strings. They can be extensions
+# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
+extensions = ['sphinx.ext.ifconfig']
+
+# Add any paths that contain templates here, relative to this directory.
+templates_path = ['_templates']
+
+# The suffix of source filenames.
+source_suffix = '.txt'
+
+# The encoding of source files.
+#source_encoding = 'utf-8'
+
+# The master toctree document.
+master_doc = 'index'
+
+# General information about the project.
+project = u'Bazaar'
+copyright = u'2009, Canonical Ltd'
+
+# The version info for the project you're documenting, acts as replacement for
+# |version| and |release|, also used in various other places throughout the
+# built documents.
+#
+# The short X.Y version.
+import bzrlib
+version = '.'.join(str(p) for p in bzrlib.version_info[:2])
+# The full version, including alpha/beta/rc tags.
+release = bzrlib.version_string
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+#language = None
+
+# There are two options for replacing |today|: either, you set today to some
+# non-false value, then it is used:
+#today = ''
+# Else, today_fmt is used as the format for a strftime call.
+#today_fmt = '%B %d, %Y'
+
+# List of documents that shouldn't be included in the build.
+#unused_docs = []
+
+# List of directories, relative to source directory, that shouldn't be searched
+# for source files.
+exclude_trees = ['_build']
+
+# The reST default role (used for this markup: `text`) to use for all documents.
+#default_role = None
+
+# If true, '()' will be appended to :func: etc. cross-reference text.
+#add_function_parentheses = True
+
+# If true, the current module name will be prepended to all description
+# unit titles (such as .. function::).
+#add_module_names = True
+
+# If true, sectionauthor and moduleauthor directives will be shown in the
+# output. They are ignored by default.
+#show_authors = False
+
+# The name of the Pygments (syntax highlighting) style to use.
+pygments_style = 'sphinx'
+
+# A list of ignored prefixes for module index sorting.
+#modindex_common_prefix = []
+
+
+# -- Options for HTML output ---------------------------------------------------
+
+# The theme to use for HTML and HTML Help pages.  Major themes that come with
+# Sphinx are currently 'default' and 'sphinxdoc'.
+html_theme = 'default'
+
+# Theme options are theme-specific and customize the look and feel of a theme
+# further.  For a list of options available for each theme, see the
+# documentation.
+html_theme_options = {
+    # Unfortunately, the right sidebar breaks under IE6 and maybe IE7.
+    # So we stick with the default left placement to cater for users stuck
+    # on those browsers.
+    #'rightsidebar': True,
+
+    # Non-document areas: header (relbar), footer, sidebar, etc.
+    # Some useful colours here:
+    # * blue: darkblue, mediumblue, darkslateblue, cornflowerblue, royalblue,
+    #   midnightblue
+    # * gray: dimgray, slategray, lightslategray
+    'sidebarbgcolor':   "cornflowerblue",
+    'sidebarlinkcolor': "midnightblue",
+    'relbarbgcolor':    "darkblue",
+    'footerbgcolor':    "lightslategray",
+
+    # Text, heading and code colouring
+    'codebgcolor':      "lightyellow",
+    'codetextcolor':    "firebrick",
+    'linkcolor':        "mediumblue",
+    }
+
+# Add any paths that contain custom themes here, relative to this directory.
+#html_theme_path = []
+
+# The name for this set of Sphinx documents.  If None, it defaults to
+# "<project> v<release> documentation".
+#html_title = None
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+#html_short_title = None
+
+# The name of an image file (relative to this directory) to place at the top
+# of the sidebar.
+#html_logo = None
+
+# The name of an image file (within the static path) to use as favicon of the
+# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
+# pixels large.
+html_favicon = "bzr.ico"
+
+# Add any paths that contain custom static files (such as style sheets) here,
+# relative to this directory. They are copied after the builtin static files,
+# so a file named "default.css" will overwrite the builtin "default.css".
+html_static_path = ['_static']
+
+# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
+# using the given strftime format.
+#html_last_updated_fmt = '%b %d, %Y'
+
+# If true, SmartyPants will be used to convert quotes and dashes to
+# typographically correct entities.
+#html_use_smartypants = True
+
+# Custom sidebar templates, maps document names to template names.
+#html_sidebars = {}
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {}
+
+# If false, no module index is generated.
+html_use_modindex = False
+
+# If false, no index is generated.
+html_use_index = False
+
+# If true, the index is split into individual pages for each letter.
+#html_split_index = False
+
+# If true, links to the reST sources are added to the pages.
+html_show_sourcelink = True
+
+# If true, an OpenSearch description file will be output, and all pages will
+# contain a <link> tag referring to it.  The value of this option must be the
+# base URL from which the finished HTML is served.
+#html_use_opensearch = ''
+
+# If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
+#html_file_suffix = ''
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-docs'
+
+
+# -- Options for LaTeX output --------------------------------------------------
+
+# The paper size ('letter' or 'a4').
+#latex_paper_size = 'letter'
+
+# The font size ('10pt', '11pt' or '12pt').
+#latex_font_size = '10pt'
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = []
+
+# The name of an image file (relative to this directory) to place at the top of
+# the title page.
+latex_logo = '../Bazaar-Logo-For-Manuals.png'
+
+# For "manual" documents, if this is true, then toplevel headings are parts,
+# not chapters.
+#latex_use_parts = False
+
+# Additional stuff for the LaTeX preamble.
+#latex_preamble = ''
+
+# Documents to append as an appendix to all manuals.
+#latex_appendices = []
+
+# If false, no module index is generated.
+#latex_use_modindex = True
+
+
+# -- Bazaar-specific configuration ---------------------------------------------
+
+# Authors of the documents
+bzr_team = u'Bazaar Developers'

=== modified file 'bzrlib/tests/test_repository.py'
--- bzrlib/tests/test_repository.py	2009-09-09 13:05:33 +0000
+++ bzrlib/tests/test_repository.py	2009-09-15 01:52:34 +0000
@@ -727,6 +727,28 @@
         # versions of the file.
         self.assertEqual(file_1_details[0][:3], file_2_details[0][:3])
 
+    def test_fetch_combines_groups(self):
+        builder = self.make_branch_builder('source', format='2a')
+        builder.start_series()
+        builder.build_snapshot('1', None, [
+            ('add', ('', 'root-id', 'directory', '')),
+            ('add', ('file', 'file-id', 'file', 'content\n'))])
+        builder.build_snapshot('2', ['1'], [
+            ('modify', ('file-id', 'content-2\n'))])
+        builder.finish_series()
+        source = builder.get_branch()
+        target = self.make_repository('target', format='2a')
+        target.fetch(source.repository)
+        target.lock_read()
+        self.addCleanup(target.unlock)
+        details = target.texts._index.get_build_details(
+            [('file-id', '1',), ('file-id', '2',)])
+        file_1_details = details[('file-id', '1')]
+        file_2_details = details[('file-id', '2')]
+        # The index, and what to read off disk, should be the same for both
+        # versions of the file.
+        self.assertEqual(file_1_details[0][:3], file_2_details[0][:3])
+
     def test_format_pack_compresses_True(self):
         repo = self.make_repository('repo', format='2a')
         self.assertTrue(repo._format.pack_compresses)

=== modified file 'bzrlib/tests/test_source.py'
--- bzrlib/tests/test_source.py	2009-06-10 03:56:49 +0000
+++ bzrlib/tests/test_source.py	2009-09-10 03:44:53 +0000
@@ -1,6 +1,4 @@
-# Copyright (C) 2005, 2006, 2008 Canonical Ltd
-#   Authors: Robert Collins <robert.collins@canonical.com>
-#            and others
+# Copyright (C) 2005, 2006, 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,12 +40,16 @@
 
 # Files which are listed here will be skipped when testing for Copyright (or
 # GPL) statements.
-COPYRIGHT_EXCEPTIONS = ['bzrlib/lsprof.py', 'bzrlib/_bencode_py.py']
+COPYRIGHT_EXCEPTIONS = ['bzrlib/lsprof.py', 'bzrlib/_bencode_py.py',
+    'bzrlib/doc_generate/sphinx_conf.py']
 
-LICENSE_EXCEPTIONS = ['bzrlib/lsprof.py', 'bzrlib/_bencode_py.py']
+LICENSE_EXCEPTIONS = ['bzrlib/lsprof.py', 'bzrlib/_bencode_py.py',
+    'bzrlib/doc_generate/sphinx_conf.py']
 # Technically, 'bzrlib/lsprof.py' should be 'bzrlib/util/lsprof.py',
 # (we do not check bzrlib/util/, since that is code bundled from elsewhere)
 # but for compatibility with previous releases, we don't want to move it.
+#
+# sphinx_conf is semi-autogenerated.
 
 
 class TestSourceHelper(TestCase):

=== removed file 'doc/BUILD-NOTES'
--- doc/BUILD-NOTES	2009-07-26 15:58:33 +0000
+++ doc/BUILD-NOTES	1970-01-01 00:00:00 +0000
@@ -1,35 +0,0 @@
-To build Bazaar's documentation using Sphinx, follow the
-steps below.
-
-0. Install Sphinx. You'll need Sphinx 0.6 or later. If that
-   version isn't available in your package manager repositories
-   yet, install python-easyinstall and use it to install Sphinx.
-   See http://sphinx.pocoo.org/ for details.
-
-1. Build the Bazaar docs normally, i.e. in the project root, run:
-
-   make docs
-
-2. Tweak the User Guide index page used:
-
-   cd doc/en/user-guide
-   bzr mv index.txt index-for-1x.txt
-   bzr mv index-for-2x.txt index.txt
-
-3. Tweak the Release Notes TOC depth:
-
-   cd ../release-notes
-   vi NEWS.txt  (change depth to 2)
-
-4. Change to the docs directory and build the site:
-
-   cd ../..
-   make html
-
-The generated output site can be found in _build/html.
-
-Note: All of the above will Just Work soon. For now, we don't
-want to break the existing doc generation until a few issues
-with the Sphinx-generated site are ironed out, e.g. links from
-the User Reference to ../user-guide/index.html#foo no longer
-work when the User Guide is nicely split into topic pages.

=== added file 'doc/Bazaar-Logo-For-Manuals.png'
Binary files doc/Bazaar-Logo-For-Manuals.png and doc/Bazaar-Logo-For-Manuals.png differ
=== removed directory 'doc/_static/en/quick-reference'
=== removed file 'doc/bazaar-vcs.org.kid'
--- doc/bazaar-vcs.org.kid	2007-08-14 03:59:22 +0000
+++ doc/bazaar-vcs.org.kid	1970-01-01 00:00:00 +0000
@@ -1,482 +0,0 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<?python
-   def update_attrib(attrib, **kwargs):
-      attrib = dict(attrib)
-      attrib.update(kwargs)
-      return attrib
-?>
-<html xmlns="http://www.w3.org/1999/xhtml" xmlns:py="http://purl.org/kid/ns#">
-<head>
-<script type="text/javascript" src=
-"/htdocs/bazaarNew/js/opacity.js">
-</script>
-<link rel="shortcut icon" href=
-"http://bazaar-vcs.org/Welcome?action=AttachFile&amp;do=get&amp;target=favicon.ico"
-type="image/x-icon" />
-<meta http-equiv="Content-Type" content=
-"text/html; charset=us-ascii" />
-<meta name="robots" content="index,follow" />
-<title>Welcome - Bazaar Version Control</title>
-
-<script type="text/javascript" src="http://bazaar-vcs.org/htdocs/common/js/common.js">
-</script>
-<script type="text/javascript">
-//<![CDATA[
-<!--// common functions
-
-// We keep here the state of the search box
-searchIsDisabled = false;
-
-function searchChange(e) {
-    // Update search buttons status according to search box content.
-    // Ignore empty or whitespace search term.
-    var value = e.value.replace(/\s+/, '');
-    if (value == '' || searchIsDisabled) { 
-        searchSetDisabled(true);
-    } else {
-        searchSetDisabled(false);
-    }
-}
-
-function searchSetDisabled(flag) {
-    // Enable or disable search
-    document.getElementById('fullsearch').disabled = flag;
-    document.getElementById('titlesearch').disabled = flag;
-}
-
-function searchFocus(e) {
-    // Update search input content on focus
-    if (e.value == 'Search') {
-        e.value = '';
-        e.className = '';
-        searchIsDisabled = false;
-    }
-}
-
-function searchBlur(e) {
-    // Update search input content on blur
-    if (e.value == '') {
-        e.value = 'Search';
-        e.className = 'disabled';
-        searchIsDisabled = true;
-    }
-}
-
-function actionsMenuInit(title) {
-    // Initialize action menu
-    for (i = 0; i < document.forms.length; i++) {
-        var form = document.forms[i];
-        if (form.className == 'actionsmenu') {
-            // Check if this form needs update
-            var div = form.getElementsByTagName('div')[0];
-            var label = div.getElementsByTagName('label')[0];
-            if (label) {
-                // This is the first time: remove label and do buton.
-                div.removeChild(label);
-                var dobutton = div.getElementsByTagName('input')[0];
-                div.removeChild(dobutton);
-                // and add menu title
-                var select = div.getElementsByTagName('select')[0];
-                var item = document.createElement('option');
-                item.appendChild(document.createTextNode(title));
-                item.value = 'show';
-                select.insertBefore(item, select.options[0]);
-                select.selectedIndex = 0;
-            }
-        }
-    }
-}
-//-->
-//]]>
-</script>
-<link rel="stylesheet" type="text/css" charset="utf-8" media="all"
-href="http://bazaar-vcs.org/htdocs/bazaarNew/css/common.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"screen" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/screen.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"print" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/print.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"projection" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/projection.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"screen" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/v4.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"screen" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/screen2.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"screen" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/twoColumnsRight.css" />
-<style type="text/css">
-a.toc-backref
-{
-    color: black;
-    text-decoration: none;
-}
-</style>
-<link rel="alternate" title="Bazaar Version Control Recent Changes"
-href="http://bazaar-vcs.org/RecentChanges?action=rss_rc&amp;ddiffs=1&amp;unique=1" type=
-"application/rss+xml" />
-<link rel="Start" href="http://bazaar-vcs.org/Welcome" />
-<link rel="Alternate" title="Wiki Markup" href=
-"http://bazaar-vcs.org/Welcome?action=raw" />
-<link rel="Alternate" media="print" title="Print View" href=
-"http://bazaar-vcs.org/Welcome?action=print" />
-<link rel="Appendix" title="favicon.ico" href=
-"http://bazaar-vcs.org/Welcome?action=AttachFile&amp;do=view&amp;target=favicon.ico" />
-<link rel="Search" href="http://bazaar-vcs.org/FindPage" />
-<link rel="Index" href="http://bazaar-vcs.org/TitleIndex" />
-<link rel="Glossary" href="http://bazaar-vcs.org/WordIndex" />
-<link rel="Help" href="http://bazaar-vcs.org/HelpOnFormatting" />
-</head>
-<body lang="en" dir="ltr" xml:lang="en">
-<div id="page_header1_div"><script type="text/javascript">
-//<![CDATA[
-gui_editor_link_text = gui_editor_link_href = null;
-//]]>
-</script></div>
-<div id="pageWrapper">
-<hr class="hide" />
-<div id="masthead" class="inside">
-<div id="logoimage"><a href="http://bazaar-vcs.org/"><img src=
-"http://bazaar-vcs.org/htdocs/bazaarNew/css/logo.png" width="144" height="149" alt=
-"Bazaar" /></a></div>
-<h1><a href="http://bazaar-vcs.org/">Bazaar</a></h1>
-<p>GPL Distributed Version Control Software</p>
-</div>
-<hr class="hide" />
-<div class="hnav">
-<ul>
-<li class="hide"><a class="hide" href="#skipToContent"><em>Skip
-Navigation</em></a> <span class="divider">:</span></li>
-<li><a href="http://bazaar-vcs.org/Documentation" id="hnav_learn" name=
-"hnav_learn">Learn</a> <span class="divider">:</span></li>
-<li><a href="http://bazaar-vcs.org/Download" id="hnav_get" name="hnav_get">Get</a>
-<span class="divider">:</span></li>
-<li><a href="http://bazaar-vcs.org/BzrSupport" id="hnav_community" name=
-"hnav_community">Community</a> <span class="divider">:</span></li>
-<li><a href="http://bazaar-vcs.org/BzrPlugins" id="hnav_plugins" name=
-"hnav_plugins">Plugins</a></li>
-</ul>
-</div>
-<div id="outerColumnContainer">
-<div id="innerColumnContainer">
-<hr class="hide" />
-<div id="leftColumn">
-<div class="inside"></div>
-</div>
-<hr class="hide" />
-<div id="rightColumn">
-<div class="inside">
-<div id="searchbox">
-<form name="search" method="get" action="http://bazaar-vcs.org/" id="search">
-<div><input type="hidden" name="action" value="fullsearch" id=
-"fullsearch" /> <input type="hidden" name="context" value="180" />
-<input type="hidden" name="fullsearch" value="Text" /> <label for=
-"search_q" py:content="'Search Wiki'">Search Bazaar</label> <input type="text" name="value"
-id="search_q" value="" onfocus="searchFocus(this)" onblur=
-"searchBlur(this)" onkeyup="searchChange(this)" onchange=
-"searchChange(this)" alt="Search" /> <input type="submit" value=
-"go" name="go" id="search_go" /></div>
-</form>
-</div>
-<div id="searchform"></div>
-<div id="username" class="vnav">
-<h4>Website Links</h4>
-<ul>
-<li><a href="http://doc.bazaar-vcs.org">Documentation</a></li>
-<li><a href="http://bazaar-vcs.org">Wiki</a></li>
-</ul>
-</div>
-</div>
-</div>
-<div id="contentColumn" class="page_Welcome">
-<hr class="hide" />
-<div id="msg" class="vnav"></div>
-<a name="skipToContent" id="skipToContent"></a>
-<div class="inside" >
-<!--<img id="navProtection" width="1" height="1" border="0" src="/htdocs/bazaarNew/css/spacer.gif" alt="" style="height: 1px"/>-->
-<a py:match="item.tag == 'a' and 'href' not in item.attrib" py:content="item.text" py:attrs="update_attrib(item.attrib, style='color: black')"/>
-<div dir="ltr" id="content" lang="en" xml:lang="en" py:content="body[:]"><span
-class="anchor" id="top"></span> <span class="anchor" id="line-8"></span>
-<h1 id="head-31592baed255c2a5cdfdaafb9521b837ea61021f">Performance
-Drive Under Way</h1>
-<span class="anchor" id="line-9"></span>
-<p class="line879">There was substantial progress on performance
-since 0.8. See <a href="/Performance/0.9">Performance/0.9</a>,
-<a href="/Performance/0.10">Performance/0.10</a> and <a href=
-"/Performance/0.11">Performance/0.11</a>. Thanks to everyone who
-has contributed patches and ideas! The focus from here to 1.0 will
-continue to be performance and documentation. Already there is work
-in progress to: <span class="anchor" id="line-10"></span></p>
-<span class="anchor" id="line-11"></span>
-<ul>
-<li>
-<p class="line879">write a <a href="/SmartServer">SmartServer</a>
-for high speed network operations (first look in 0.11).
-<span class="anchor" id="line-12"></span></p>
-</li>
-<li>
-<p class="line886">optimise file system access (tune our code and
-data structures to minimise probable disk io and disk seeking)
-<span class="anchor" id="line-13"></span></p>
-</li>
-<li>
-<p class="line886">optimise file formats for performance without
-sacrificing proven correctness and completeness <span class=
-"anchor" id="line-14"></span></p>
-</li>
-<li>
-<p class="line886">tune the codepaths that are most heavily used
-<span class="anchor" id="line-15"></span></p>
-</li>
-<li>
-<p class="line886">ensure that large imports are only done when
-needed, and use lightweight imports where possible <span class=
-"anchor" id="line-16"></span></p>
-<span class="anchor" id="line-17"></span></li>
-</ul>
-<h1 id="head-ceb9b8e0146b0ce087048f495b2ff2964c5d57ec">News</h1>
-<span class="anchor" id="line-18"></span>
-<h2 id="head-39a1524e97c9a6ba89ecee7856cb1a2e68134373">27th
-September 2006 - 0.11rc2 released</h2>
-<span class="anchor" id="line-19"></span>
-<p class="line879">bzr 0.11rc2 has been released. This release
-candidate corrects two regressions that occured from 0.10. Windows
-developers and users with very large source trees should upgrade
-immediately. Release <a class="https" href=
-"https://lists.canonical.com/archives/bazaar-ng/2006q3/017581.html">
-announcement</a> or <a class="http" href=
-"http://bazaar-vcs.org/releases/src/bzr-0.11rc2.tar.gz">download
-now</a>. For details of the original 0.11 release candidate, see
-the <a class="https" href=
-"https://lists.canonical.com/archives/bazaar-ng/2006q3/017502.html">
-announcement</a>. <span class="anchor" id="line-20"></span></p>
-<span class="anchor" id="line-21"></span>
-<h2 id="head-9940b3014f81c7b8ca65aa3235341588859d09dd">4th
-September 2006 - 0.10 released</h2>
-<span class="anchor" id="line-22"></span>
-<p class="line879">bzr 0.10 has been released after a smooth beta
-period. <a class="http" href=
-"http://bazaar-vcs.org/releases/src/bzr-0.10.tar.gz">download it
-now</a>! <span class="anchor" id="line-23"></span></p>
-<span class="anchor" id="line-24"></span>
-<h1 id="head-c2a87bc7d0bc411d33e18585154e534201115501">What is
-Bazaar?</h1>
-<span class="anchor" id="line-25"></span>
-<p class="line879">Bazaar is a decentralized revision control
-system designed to be easy for developers and end users alike.
-Decentralized revision control systems give people the ability to
-work over the internet using the <a class="http" href=
-"http://en.wikipedia.org/wiki/The_Cathedral_and_the_Bazaar">bazaar
-development model</a>. When you use Bazaar, you can commit to your
-own branches of your favorite free software projects without
-needing special permission. For more information, see: <span class=
-"anchor" id="line-26"></span></p>
-<span class="anchor" id="line-27"></span>
-<ul>
-<li>
-<p class="line903"><a href="/Bzr">What Is Bazaar?</a> <span class=
-"anchor" id="line-28"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/WhoUsesBzr">Who Uses Bazaar?</a>
-<span class="anchor" id="line-29"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrFeatures">Bazaar Features</a>
-<span class="anchor" id="line-30"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/FAQ">FAQ</a> (Frequently Asked
-Questions) <span class="anchor" id="line-31"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrGlossary">Bazaar Glossary</a>
-<span class="anchor" id="line-32"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/ReleaseRoadmap">What's Coming</a> (the
-release roadmap) <span class="anchor" id="line-33"></span></p>
-<span class="anchor" id="line-34"></span></li>
-</ul>
-<h1 id="head-54a84f21f8314a452aecfb4e2da59fcb246fee7b">Where do I
-get it?</h1>
-<span class="anchor" id="line-35"></span>
-<p class="line886">The easiest place to get Bazaar is with your
-distribution. Do not despair if your distribution does not have
-Bazaar, as plain installation is still easy. <span class="anchor"
-id="line-36"></span></p>
-<span class="anchor" id="line-37"></span>
-<ul>
-<li>
-<p class="line903"><a href="/DistroDownloads">Packages</a> -
-Downloads for various distributions <span class="anchor" id=
-"line-38"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/OfficialDownloads">Source</a> - Source
-downloads <span class="anchor" id="line-39"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/WindowsDownloads">Windows</a> -
-Downloads for windows <span class="anchor" id="line-40"></span></p>
-<span class="anchor" id="line-41"></span></li>
-</ul>
-<h1 id="head-400b61668c5f3ab729ffbfeed0f9fc93e853044e">How do I
-install it?</h1>
-<span class="anchor" id="line-42"></span>
-<p class="line879">Installation for Bazaar is a snap. Supported
-operating systems include Linux, FreeBSD, Windows (Native &amp;
-Cygwin) and Solaris. If you can run Python 2.4, then you can run
-Bazaar. <span class="anchor" id="line-43"></span></p>
-<span class="anchor" id="line-44"></span>
-<ul>
-<li>
-<p class="line903"><a href="/DistroDownloads">Packages</a> -
-Downloads for various distributions <span class="anchor" id=
-"line-45"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/Installation">Generic</a> - Generic
-Installation Instructions. <span class="anchor" id=
-"line-46"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrOnPureWindows">Native Windows</a> -
-Installation of Bazaar on Native windows. <span class="anchor" id=
-"line-47"></span></p>
-<span class="anchor" id="line-48"></span></li>
-</ul>
-<h1 id="head-6350ee8bfd03b56b430e775595af1eb29ac7bdb4">How do I use
-it?</h1>
-<span class="anchor" id="line-49"></span>
-<p class="line886">Included are the pearls of wisdom from people
-that have already branched off into a new world of development.
-<span class="anchor" id="line-50"></span></p>
-<span class="anchor" id="line-51"></span>
-<ul>
-<li>
-<p class="line903"><a href="/Documentation">Documents</a> - The
-main documentation page for Bazaar. <span class="anchor" id=
-"line-52"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/IntroductionToBzr">Introduction</a> -
-Introduction to Bazaar gives a walkthough of the simpler commands.
-<span class="anchor" id="line-53"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/QuickHackingWithBzr">Mini Tutorial</a>
-- The five minutes Bazaar Tutorial. <span class="anchor" id=
-"line-54"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrRevisionSpec">Revision Specs</a> -
-Arguments for -r that can be given with "bzr log", "bzr merge" and
-such. <span class="anchor" id="line-55"></span></p>
-<span class="anchor" id="line-56"></span></li>
-</ul>
-<h1 id="head-148c5debbd034308b67411c490e69555ee5a03a3">How does it
-compare?</h1>
-<span class="anchor" id="line-57"></span>
-<p class="line886">If you're familiar with other version control
-systems, you might like to see a quick comparison to them, or read
-guidelines to help you understand how to use bzr most effectively
-given your current experience. <span class="anchor" id=
-"line-58"></span></p>
-<span class="anchor" id="line-59"></span>
-<ul>
-<li>
-<p class="line903"><a href="/BzrForCVSUsers">BzrForCVSUsers</a> -
-Learning Bazaar for CVS users. <span class="anchor" id=
-"line-60"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrForGITUsers">BzrForGITUsers</a> -
-(In progress) Learning Bazaar for GIT users <span class="anchor"
-id="line-61"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/RcsComparisons">RcsComparisons</a> -
-Comparison table of functionality and performance with Bazaar, GIT,
-Mercurial, SVN and other VCS systems. <span class="anchor" id=
-"line-62"></span></p>
-<span class="anchor" id="line-63"></span></li>
-</ul>
-<h1 id="head-e966f9f6520262482dc713218b2a916600636f14">How can I
-get Help?</h1>
-<span class="anchor" id="line-64"></span>
-<p class="line879">Our primary page for getting help is the
-<a href="/BzrSupport">BzrSupport</a> page. <span class="anchor" id=
-"line-65"></span></p>
-<span class="anchor" id="line-66"></span>
-<ul>
-<li>
-<p class="line903"><a class="https" href=
-"https://launchpad.net/products/bzr/+bugs">Bug Tracker</a> - You
-can check here to see if someone else is experiencing the same
-problem that you are. <span class="anchor" id="line-67"></span></p>
-</li>
-<li>
-<p class="line903"><a class="http" href=
-"http://lists.canonical.com/mailman/listinfo/bazaar-ng">Mailing
-List</a> - A high volume list focused upon Bazaar development and
-support. <span class="anchor" id="line-68"></span></p>
-</li>
-<li>
-<p class="line886">IRC - #bzr on irc.freenode.net <span class=
-"anchor" id="line-69"></span></p>
-<span class="anchor" id="line-70"></span></li>
-</ul>
-<h1 id="head-45d36005ff61e184525081c9c40ed26ded3c8f02">How can I
-contribute?</h1>
-<span class="anchor" id="line-71"></span>
-<p class="line879">Our primary development doc page is <a href=
-"/BzrDevelopment">BzrDevelopment</a>. <span class="anchor" id=
-"line-72"></span></p>
-<span class="anchor" id="line-73"></span>
-<ul>
-<li>
-<p class="line903"><a href="/BzrDevelopment">Development
-Instructions</a> - We keep our main development instructions here.
-<span class="anchor" id="line-74"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/OfficialDownloads">Source Code</a> -
-Source code to get hacking with. <span class="anchor" id=
-"line-75"></span></p>
-</li>
-<li>
-<p class="line903"><a class="https" href=
-"https://launchpad.net/products/bzr/+specs">Specifications</a> -
-Specifications list which things are being worked on today and are
-likely to be worked on next. <span class="anchor" id=
-"line-76"></span></p>
-</li>
-<li>
-<p class="line903"><a class="https" href=
-"https://launchpad.net/products/bzr/+bugs">BugTracker</a> - Open
-bugs that you can work on. <span class="anchor" id=
-"line-77"></span></p>
-<span class="anchor" id="line-78"></span></li>
-</ul>
-<p class="line879">You are also welcome to improve this wiki site.
-To edit pages, please <a href="/UserPreferences">register</a>.
-Anonymous editing is disabled to prevent spammer attacks.
-<span class="anchor" id="line-79"></span></p>
-<span class="anchor" id="bottom"></span></div>
-</div>
-<div class="clear mozclear"></div>
-</div>
-</div>
-<div class="hide" id="nsFooterClear"><!-- for NS4's sake --></div>
-<hr class="hide" />
-<div id="footer" class="inside">
-<p style="margin:0;">&copy; 2006 - <a href=
-"http://canonical.com/">Canonical Ltd.</a></p>
-<div id="endofpage"></div>
-<div id="footer_custom_html"></div>
-<div id="footer_links"></div>
-</div>
-<hr class="hide" /></div>
-</div>
-</body>
-</html>

=== renamed file 'doc/en/developer-guide/HACKING.txt' => 'doc/developers/HACKING.txt'
--- doc/en/developer-guide/HACKING.txt	2009-08-13 17:16:31 +0000
+++ doc/developers/HACKING.txt	2009-09-09 12:57:43 +0000
@@ -11,14 +11,8 @@
 the Bazaar mailing list.  To propose a correction or addition to this
 document, send a merge request or new text to the mailing list.
 
-The current version of this document is available in the file 
-``doc/en/developer-guide/HACKING.txt`` in the source tree, or at
-http://doc.bazaar-vcs.org/bzr.dev/en/developer-guide/HACKING.html
-
-See also:
-`Bazaar Developer Documentation Catalog <../../developers/index.html>`_.
-
-.. contents::
+The latest developer documentation can be found online at
+http://doc.bazaar-vcs.org/developers/.
 
 
 Getting Started
@@ -266,7 +260,8 @@
 Automatically-generated API reference information is available at 
 <http://starship.python.net/crew/mwh/bzrlibapi/>.  
 
-See also the `Bazaar Architectural Overview  <../../developers/overview.html>`_.
+See also the `Bazaar Architectural Overview
+<http://doc.bazaar-vcs.org/developers/overview.html>`_.
 
 
 The Code Review Process
@@ -841,8 +836,9 @@
 Test coverage
 =============
 
-All code should be exercised by the test suite.  See `Guide to Testing
-Bazaar <../../developers/testing.html>`_ for detailed information about writing tests.
+All code should be exercised by the test suite.  See the `Bazaar Testing
+Guide <http://doc.bazaar-vcs.org/developers/testing.html>`_ for detailed
+information about writing tests.
 
 
 Core Topics
@@ -1403,7 +1399,7 @@
 * reviewing changes
 * reviewing blueprints
 * planning releases
-* managing releases (see the `Releasing Bazaar <../../developers/releasing.html>`_)
+* managing releases (see `Releasing Bazaar <http://doc.bazaar-vcs.org/developers/releasing.html>`_)
 
 .. note::
   Removing barriers to community participation is a key reason for adopting

=== added directory 'doc/developers/_static'
=== added file 'doc/developers/_static/bzr icon 16.png'
Binary files doc/developers/_static/bzr icon 16.png and doc/developers/_static/bzr icon 16.png differ
=== added file 'doc/developers/_static/bzr.ico'
Binary files doc/developers/_static/bzr.ico and doc/developers/_static/bzr.ico differ
=== added directory 'doc/developers/_templates'
=== added file 'doc/developers/_templates/layout.html'
--- doc/developers/_templates/layout.html	1970-01-01 00:00:00 +0000
+++ doc/developers/_templates/layout.html	2009-09-07 07:44:36 +0000
@@ -0,0 +1,8 @@
+{% extends "!layout.html" %}
+
+{% block rootrellink %}
+<li><a href="http://bazaar-vcs.org/">
+    <img src="{{ pathto("_static/bzr icon 16.png", 1) }}" /> Home</a>&nbsp;|&nbsp;</li>
+<a href="http://doc.bazaar-vcs.org/en/">Documentation</a>&nbsp;|&nbsp;</li>
+{{ super() }}
+{% endblock %}

=== added file 'doc/developers/conf.py'
--- doc/developers/conf.py	1970-01-01 00:00:00 +0000
+++ doc/developers/conf.py	2009-09-09 15:51:18 +0000
@@ -0,0 +1,71 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# This file is execfile()d with the current directory set to its containing dir.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'en'
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+html_short_title = u"Developer Document Catalog (%s)" % (release,)
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {'index': 'index.html'}
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-developers'
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = [
+  ('HACKING', 'bzr-en-developer-guide.tex', u'Bazaar Developer Guide',
+   u'Bazaar Developers', 'manual'),
+  ('testing', 'bzr-en-testing-guide.tex', u'Bazaar Testing Guide',
+   u'Bazaar Developers', 'manual'),
+  ('overview', 'bzr-en-architecture-overview.tex', u'Bazaar Architecture Overview',
+   u'Bazaar Developers', 'howto'),
+  ('integration', 'bzr-en-integration-guide.tex', u'Bazaar Integration Guide',
+   u'Bazaar Developers', 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+# Note: Maybe some of them *ought* to be linked in somewhere?
+unused_docs = [
+  'add',
+  'annotate',
+  'bundle-creation',
+  'bundle-format4',
+  'check',
+  'commit',
+  'diff',
+  'directory-fingerprints',
+  'gc',
+  'index-plain',
+  'incremental-push-pull',
+  'initial-push-pull',
+  'merge-scaling',
+  'missing',
+  'performance-roadmap-rationale',
+  'performance-use-case-analysis',
+  'planned-change-integration',
+  'planned-performance-changes',
+  'revert',
+  'status',
+  'uncommit',
+]

=== modified file 'doc/developers/dirstate.txt'
--- doc/developers/dirstate.txt	2007-06-18 02:04:20 +0000
+++ doc/developers/dirstate.txt	2009-09-09 15:51:18 +0000
@@ -1,3 +1,6 @@
+Dirstate
+========
+
 Don't really need the hashes of the current versions - just knowing
 whether they've changed or not will generally be enough - and just the
 mtime and ctime of a point in time may be enough?

=== added file 'doc/developers/implementation-notes.txt'
--- doc/developers/implementation-notes.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/implementation-notes.txt	2009-09-07 07:44:36 +0000
@@ -0,0 +1,28 @@
+Implementation notes
+====================
+
+.. toctree::
+   :hidden:
+
+   btree_index_prefetch
+   last-modified
+   content-filtering
+   lca_tree_merging
+
+
+* `BTree Index Prefetch <btree_index_prefetch.html>`_ |--| How bzr decides
+  to pre-read extra nodes in the btree index.
+
+* `Computing last_modified values <last-modified.html>`_ for inventory
+  entries
+
+* `Content filtering <content-filtering.html>`_
+
+* `LCA Tree Merging <lca_tree_merging.html>`_ |--| Merging tree-shape when
+  there is not a single unique ancestor (criss-cross merge).
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== added file 'doc/developers/index-plain.txt'
--- doc/developers/index-plain.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/index-plain.txt	2009-09-09 12:57:43 +0000
@@ -0,0 +1,146 @@
+=================================
+Bazaar Developer Document Catalog
+=================================
+
+
+Overall developer documentation
+===============================
+
+* `Developer Guide <HACKING.html>`_
+
+* `Architectural Overview <overview.html>`_ |--| describes some of the
+  most important classes and concepts.
+
+* `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_ 
+  (external link)
+  |--| automatically generated API reference information
+
+* `Integrating with Bazaar <http://bazaar-vcs.org/Integrating_with_Bazaar>`_
+  (wiki) |--| a guide for writing Python programs that work with Bazaar.
+
+* `Revision Properties <revision-properties.html>`_ |--| An application
+  can set arbitrary per-revision key/value pairs to store app-specific
+  data.
+
+* `Testing <testing.html>`_ |--| Guide to writing tests for Bazaar.
+
+* `Writing plugins <http://bazaar-vcs.org/WritingPlugins>`_ (wiki) 
+  |--| specific advice on writing Bazaar plugins.
+
+Process
+=======
+
+* `The Bazaar Development Cycle <cycle.html>`_ |--| The monthly
+  development cycle and how to run it.
+  
+* `Releasing Bazaar <releasing.html>`_ |--| 
+  Checklist to make a release of Bazaar.
+
+* `Managing the Bazaar PPA <ppa.html>`_ |--| Packaging Bazaar for Ubuntu.
+
+* `Giving back <http://bazaar-vcs.org/BzrGivingBack>`_ (wiki) |--| How to get
+  your changes to Bazaar integrated into a release.
+
+* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile 
+  bzr code and visualize the results.
+
+* `EC2 resources <ec2.html>`_ |--| A team resource for 
+  Windows packaging and testing, and Ubuntu testing.
+
+* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug 
+  tracker.
+
+Plans
+=====
+
+* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap 
+  for fixing performance in bzr over the next few releases.
+
+* `Co-located branches <colocated-branches.html>`_ |--| Planned(?) support
+  for storing multiple branches in one file-system directory.
+
+* `Bazaar Windows Shell Extension Options <tortoise-strategy.html>`_ |--|
+  Implmentation strategy for Bazaar Windows Shell Extensions, aka
+  TortoiseBzr.
+
+* `CHK Optimized index <improved_chk_index.html>`_
+
+Specifications
+==============
+
+* `API versioning <api-versioning.html>`_ |--| bzrlib API versioning.
+
+* `Apport error reporting <apport.html>`_ |--| Capture data to report
+  bugs.
+
+* `Authentication ring <authentication-ring.html>`_ |--| Configuring
+  authentication.
+
+* `Bundles <bundles.html>`_ |--| All about bzr bundles.
+
+* `Container format <container-format.html>`_ |--| Notes on a container format
+  for streaming and storing Bazaar data.
+
+* `Groupcompress <groupcompress-design.html>`_ |--| Notes on the compression
+  technology used in CHK repositories.
+
+* `Indices <indices.html>`_ |--| The index facilities available within bzrlib.
+
+* `Inventories <inventory.html>`_ |--| Tree shape abstraction.
+
+* `LCA merge <lca-merge.html>`_ |--| A nice new merge algorithm.
+
+* `Network protocol <network-protocol.html>`_ |--| Custom network protocol.
+
+* `Plugin APIs <plugin-api.html>`_ |--| APIs plugins should use.
+
+* `Repositories <repository.html>`_ |--| What repositories do and are used for.
+
+* `Repository stream <repository-stream.html>`_ |--| Notes on streaming data
+  for repositories (a layer above the container format).
+
+* `Integration Guide <integration.html>`_ |--| A guide to integrate bzrlib into
+  any python application.
+
+* `Bazaar and case-insensitive file systems <case-insensitive-file-systems.html>`_
+  |--| How Bazaar operates on case-insensitive file systems such as commonly
+  found on Windows, USB sticks, etc.
+
+* `Development repository formats <development-repo.html>`_ |--| How to
+  work with repository formats that are still under development.
+  Contains instructions for those implementing new formats, of course,
+  but also for (bleeding-edge) end users of those formats.
+
+Data formats
+============
+
+* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories 
+  (new in Bazaar 0.92).
+
+Implementation notes
+====================
+
+* `BTree Index Prefetch <btree_index_prefetch.html>`_ |--| How bzr decides
+  to pre-read extra nodes in the btree index.
+
+* `Computing last_modified values <last-modified.html>`_ for inventory
+  entries
+
+* `Content filtering <content-filtering.html>`_
+
+* `LCA Tree Merging <lca_tree_merging.html>`_ |--| Merging tree-shape when
+  there is not a single unique ancestor (criss-cross merge).
+
+Miscellaneous
+=============
+
+* `dirstate <dirstate.html>`_ |--| An observation re. the dirstate file
+
+* `"bzr update" performance analysis <update.html>`_ |--| "bzr update"
+  performance analysis
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/index.txt'
--- doc/developers/index.txt	2009-08-28 05:00:33 +0000
+++ doc/developers/index.txt	2009-09-11 07:55:48 +0000
@@ -2,142 +2,44 @@
 Bazaar Developer Document Catalog
 =================================
 
-
-Overall developer documentation
-===============================
-
-* `Developer Guide <../en/developer-guide/HACKING.html>`_
-
-* `Architectural Overview <overview.html>`_ |--| describes some of the
-  most important classes and concepts.
+Enhancing Bazaar
+================
+
+.. toctree::
+   :maxdepth: 1
+
+   process
+   HACKING
+   testing
+
+* `Bazaar Writer Guide <http://bazaar-vcs.org/ContributingToTheDocs>`_ (web link)
+
+
+Developing using bzrlib
+=======================
+
+.. toctree::
+   :maxdepth: 1
+
+   overview
+   integration
+
+* `Writing plugins for Bazaar <http://bazaar-vcs.org/WritingPlugins>`_ (web link) 
 
 * `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_ 
-  (external link)
-  |--| automatically generated API reference information
-
-* `Integrating with Bazaar <http://bazaar-vcs.org/Integrating_with_Bazaar>`_
-  (wiki) |--| a guide for writing Python programs that work with Bazaar.
-
-* `Revision Properties <revision-properties.html>`_ |--| An application
-  can set arbitrary per-revision key/value pairs to store app-specific
-  data.
-
-* `Testing <testing.html>`_ |--| Guide to writing tests for Bazaar.
-
-* `Writing plugins <http://bazaar-vcs.org/WritingPlugins>`_ (wiki) 
-  |--| specific advice on writing Bazaar plugins.
-
-Process
-=======
-
-* `The Bazaar Development Cycle <cycle.html>`_ |--| The monthly
-  development cycle and how to run it.
-  
-* `Releasing Bazaar <releasing.html>`_ |--| 
-  Checklist to make a release of Bazaar.
-
-* `Managing the Bazaar PPA <ppa.html>`_ |--| Packaging Bazaar for Ubuntu.
-
-* `Giving back <http://bazaar-vcs.org/BzrGivingBack>`_ (wiki) |--| How to get
-  your changes to Bazaar integrated into a release.
-
-* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile 
-  bzr code and visualize the results.
-
-* `EC2 resources <ec2.html>`_ |--| A team resource for 
-  Windows packaging and testing, and Ubuntu testing.
-
-* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug 
-  tracker.
-
-Plans
-=====
-
-* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap 
-  for fixing performance in bzr over the next few releases.
-
-* `Co-located branches <colocated-branches.html>`_ |--| Planned(?) support
-  for storing multiple branches in one file-system directory.
-
-* `Bazaar Windows Shell Extension Options <tortoise-strategy.html>`_ |--|
-  Implmentation strategy for Bazaar Windows Shell Extensions, aka
-  TortoiseBzr.
-
-* `CHK Optimized index <improved_chk_index.html>`_
-
-Specifications
-==============
-
-* `API versioning <api-versioning.html>`_ |--| bzrlib API versioning.
-
-* `Apport error reporting <apport.html>`_ |--| Capture data to report
-  bugs.
-
-* `Authentication ring <authentication-ring.html>`_ |--| Configuring
-  authentication.
-
-* `Bundles <bundles.html>`_ |--| All about bzr bundles.
-
-* `Container format <container-format.html>`_ |--| Notes on a container format
-  for streaming and storing Bazaar data.
-
-* `Groupcompress <groupcompress-design.html>`_ |--| Notes on the compression
-  technology used in CHK repositories.
-
-* `Indices <indices.html>`_ |--| The index facilities available within bzrlib.
-
-* `Inventories <inventory.html>`_ |--| Tree shape abstraction.
-
-* `LCA merge <lca-merge.html>`_ |--| A nice new merge algorithm.
-
-* `Network protocol <network-protocol.html>`_ |--| Custom network protocol.
-
-* `Plugin APIs <plugin-api.html>`_ |--| APIs plugins should use.
-
-* `Repositories <repository.html>`_ |--| What repositories do and are used for.
-
-* `Repository stream <repository-stream.html>`_ |--| Notes on streaming data
-  for repositories (a layer above the container format).
-
-* `Integration Guide <integration.html>`_ |--| A guide to integrate bzrlib into
-  any python application.
-
-* `Bazaar and case-insensitive file systems <case-insensitive-file-systems.html>`_
-  |--| How Bazaar operates on case-insensitive file systems such as commonly
-  found on Windows, USB sticks, etc.
-
-* `Development repository formats <development-repo.html>`_ |--| How to
-  work with repository formats that are still under development.
-  Contains instructions for those implementing new formats, of course,
-  but also for (bleeding-edge) end users of those formats.
-
-Data formats
-============
-
-* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories 
-  (new in Bazaar 0.92).
-
-Implementation notes
-====================
-
-* `BTree Index Prefetch <btree_index_prefetch.html>`_ |--| How bzr decides
-  to pre-read extra nodes in the btree index.
-
-* `Computing last_modified values <last-modified.html>`_ for inventory
-  entries
-
-* `Content filtering <content-filtering.html>`_
-
-* `LCA Tree Merging <lca_tree_merging.html>`_ |--| Merging tree-shape when
-  there is not a single unique ancestor (criss-cross merge).
-
-Miscellaneous
-=============
-
-* `dirstate <dirstate.html>`_ |--| An observation re. the dirstate file
-
-* `"bzr update" performance analysis <update.html>`_ |--| "bzr update"
-  performance analysis
+  (web link)
+
+
+Other documents
+===============
+
+.. toctree::
+   :maxdepth: 1
+
+   plans
+   specifications
+   implementation-notes
+   miscellaneous-notes
 
 
 .. |--| unicode:: U+2014

=== modified file 'doc/developers/integration.txt'
--- doc/developers/integration.txt	2008-04-08 10:55:41 +0000
+++ doc/developers/integration.txt	2009-09-09 02:21:47 +0000
@@ -244,12 +244,12 @@
 
   source.create_checkout('/tmp/newBzrCheckout', None, False, accelerator_tree
 
-==================
+
 History Operations
 ==================
 
 Finding the last revision number or id
-======================================
+--------------------------------------
 
 To get the last revision number and id of a branch use::
 
@@ -263,7 +263,7 @@
 
 
 Getting the list of revision ids that make up a branch
-======================================================
+------------------------------------------------------
 
 IMPORTANT: This should be avoided wherever possible, as it scales with the
 length of history::
@@ -277,7 +277,7 @@
 
 
 Getting a Revision object from a revision id
-============================================
+--------------------------------------------
 
 The Revision object has attributes like "message" to get the information
 about the revision::
@@ -287,7 +287,7 @@
 
 
 Accessing the files from a revision
-===================================
+-----------------------------------
 
 To get the file contents and tree shape for a specific revision you need
 a RevisionTree. These are supplied by the repository for a specific

=== added file 'doc/developers/miscellaneous-notes.txt'
--- doc/developers/miscellaneous-notes.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/miscellaneous-notes.txt	2009-09-07 07:44:36 +0000
@@ -0,0 +1,20 @@
+Miscellaneous notes
+===================
+
+.. toctree::
+   :hidden:
+
+   dirstate
+   update
+
+
+* `dirstate <dirstate.html>`_ |--| An observation re. the dirstate file
+
+* `"bzr update" performance analysis <update.html>`_ |--| "bzr update"
+  performance analysis
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/overview.txt'
--- doc/developers/overview.txt	2009-03-20 02:08:23 +0000
+++ doc/developers/overview.txt	2009-09-08 01:11:40 +0000
@@ -12,16 +12,9 @@
 document, send a merge request or new text to the mailing list.
 
 The current version of this document is available in the file
-``doc/developers/overview.txt`` in the source tree, and from 
-<http://doc.bazaar-vcs.org/bzr.dev/>.
-
-See also:
-
- * `Bazaar Developer Documentation Catalog <index.html>`_.
- * `Bazaar Developer Guide <../en/developer-guide/HACKING.html>`_
-   (particularly the *Coding Style Guidelines* section.)
-
-.. contents::
+``doc/developers/overview.txt`` in the source tree, and available online 
+within the developer documentation, <http://doc.bazaar-vcs.org/developers/>.
+
 
 Essential Domain Classes
 ########################

=== added file 'doc/developers/plans.txt'
--- doc/developers/plans.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/plans.txt	2009-09-07 07:44:36 +0000
@@ -0,0 +1,29 @@
+Plans
+=====
+
+.. toctree::
+   :hidden:
+
+   performance-roadmap
+   colocated-branches
+   tortoise-strategy
+   improved_chk_index
+
+
+* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap 
+  for fixing performance in bzr over the next few releases.
+
+* `Co-located branches <colocated-branches.html>`_ |--| Planned(?) support
+  for storing multiple branches in one file-system directory.
+
+* `Bazaar Windows Shell Extension Options <tortoise-strategy.html>`_ |--|
+  Implmentation strategy for Bazaar Windows Shell Extensions, aka
+  TortoiseBzr.
+
+* `CHK Optimized index <improved_chk_index.html>`_
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== added file 'doc/developers/process.txt'
--- doc/developers/process.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/process.txt	2009-09-09 02:21:47 +0000
@@ -0,0 +1,39 @@
+Bazaar Development Processes
+============================
+
+.. toctree::
+   :hidden:
+
+   cycle
+   releasing
+   ppa
+   profiling
+   ec2
+   bug-handling
+
+
+* `The Bazaar Development Cycle <cycle.html>`_ |--| The monthly
+  development cycle and how to run it.
+  
+* `Releasing Bazaar <releasing.html>`_ |--| 
+  Checklist to make a release of Bazaar.
+
+* `Managing the Bazaar PPA <ppa.html>`_ |--| Packaging Bazaar for Ubuntu.
+
+* `Giving back <http://bazaar-vcs.org/BzrGivingBack>`_ (wiki) |--| How to get
+  your changes to Bazaar integrated into a release.
+
+* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile 
+  bzr code and visualize the results.
+
+* `EC2 resources <ec2.html>`_ |--| A team resource for 
+  Windows packaging and testing, and Ubuntu testing.
+
+* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug 
+  tracker.
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2009-08-30 21:34:42 +0000
+++ doc/developers/releasing.txt	2009-09-11 07:55:48 +0000
@@ -3,7 +3,8 @@
 
 This document describes the processes for making and announcing a Bazaar
 release, and managing the release process.  This is just one phase of the 
-`overall development cycle <cycle.html>`_, but it's the most complex part.
+`overall development cycle <http://doc.bazaar-vcs.org/developers/cycle.html>`_,
+but it's the most complex part.
 This document gives a checklist you can follow from start to end in one
 go.
 
@@ -81,7 +82,7 @@
 	submit_to = bazaar@lists.canonical.com
 	smtp_server = mail.example.com:25
 
-    Please see <http://doc.bazaar-vcs.org/latest/developers/HACKING.html#an-overview-of-pqm>
+    Please see <http://doc.bazaar-vcs.org/developers/HACKING.html#an-overview-of-pqm>
     for more details on PQM
 
 #. In the release branch, update  ``version_info`` in ``./bzrlib/__init__.py``.

=== added file 'doc/developers/specifications.txt'
--- doc/developers/specifications.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/specifications.txt	2009-09-07 07:44:36 +0000
@@ -0,0 +1,77 @@
+Specifications
+==============
+
+.. toctree::
+   :hidden:
+
+   revision-properties
+   api-versioning
+   apport
+   authentication-ring
+   bundles
+   container-format
+   groupcompress-design
+   indices
+   inventory
+   lca-merge
+   network-protocol
+   plugin-api
+   repository
+   repository-stream
+   case-insensitive-file-systems
+   development-repo
+   packrepo
+
+
+* `Revision Properties <revision-properties.html>`_ |--| An application
+  can set arbitrary per-revision key/value pairs to store app-specific
+  data.
+
+* `API versioning <api-versioning.html>`_ |--| bzrlib API versioning.
+
+* `Apport error reporting <apport.html>`_ |--| Capture data to report
+  bugs.
+
+* `Authentication ring <authentication-ring.html>`_ |--| Configuring
+  authentication.
+
+* `Bundles <bundles.html>`_ |--| All about bzr bundles.
+
+* `Container format <container-format.html>`_ |--| Notes on a container format
+  for streaming and storing Bazaar data.
+
+* `Groupcompress <groupcompress-design.html>`_ |--| Notes on the compression
+  technology used in CHK repositories.
+
+* `Indices <indices.html>`_ |--| The index facilities available within bzrlib.
+
+* `Inventories <inventory.html>`_ |--| Tree shape abstraction.
+
+* `LCA merge <lca-merge.html>`_ |--| A nice new merge algorithm.
+
+* `Network protocol <network-protocol.html>`_ |--| Custom network protocol.
+
+* `Plugin APIs <plugin-api.html>`_ |--| APIs plugins should use.
+
+* `Repositories <repository.html>`_ |--| What repositories do and are used for.
+
+* `Repository stream <repository-stream.html>`_ |--| Notes on streaming data
+  for repositories (a layer above the container format).
+
+* `Bazaar and case-insensitive file systems <case-insensitive-file-systems.html>`_
+  |--| How Bazaar operates on case-insensitive file systems such as commonly
+  found on Windows, USB sticks, etc.
+
+* `Development repository formats <development-repo.html>`_ |--| How to
+  work with repository formats that are still under development.
+  Contains instructions for those implementing new formats, of course,
+  but also for (bleeding-edge) end users of those formats.
+
+* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories 
+  (new in Bazaar 0.92).
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/testing.txt'
--- doc/developers/testing.txt	2009-09-02 23:45:04 +0000
+++ doc/developers/testing.txt	2009-09-11 07:55:48 +0000
@@ -1,11 +1,7 @@
-=======================
-Guide to Testing Bazaar
-=======================
-
-.. contents::
-
-Testing Bazaar
-##############
+====================
+Bazaar Testing Guide
+====================
+
 
 The Importance of Testing
 =========================

=== renamed file 'doc/Makefile' => 'doc/en/Makefile'
=== renamed directory 'doc/_static' => 'doc/en/_static'
=== renamed file 'doc/_static/en/quick-reference/Makefile' => 'doc/en/_static/en/Makefile'
--- doc/_static/en/quick-reference/Makefile	2009-07-22 14:07:56 +0000
+++ doc/en/_static/en/Makefile	2009-09-09 00:49:50 +0000
@@ -2,8 +2,8 @@
 # doc/*/quick-reference/Makefile and update TARGETS and OBJECTS usages in
 # doc/Makefile
 
-TARGETS=bzr-quick-reference.png bzr-quick-reference.pdf
-OBJECTS=bzr-quick-reference.svg Makefile
+TARGETS=bzr-en-quick-reference.png bzr-en-quick-reference.pdf
+OBJECTS=bzr-en-quick-reference.svg Makefile
 
 all: $(TARGETS)
 
@@ -15,9 +15,9 @@
 .svg.png:
 	rsvg-convert -d 300 -p 300 -z 3.3346 -f png -o $@ $<
 
-bzr-quickref.png: $(OBJECTS)
+bzr-en-quick-reference.png: $(OBJECTS)
 
-bzr-quickref.pdf: $(OBJECTS)
+bzr-en-quick-reference.pdf: $(OBJECTS)
 
 clean:
 	rm -f $(TARGETS)

=== renamed file 'doc/_static/en/quick-reference/bzr-quick-reference.pdf' => 'doc/en/_static/en/bzr-en-quick-reference.pdf'
=== renamed file 'doc/_static/en/quick-reference/bzr-quick-reference.png' => 'doc/en/_static/en/bzr-en-quick-reference.png'
=== renamed file 'doc/_static/en/quick-reference/bzr-quick-reference.svg' => 'doc/en/_static/en/bzr-en-quick-reference.svg'
=== renamed directory 'doc/_templates' => 'doc/en/_templates'
=== modified file 'doc/en/_templates/index.html'
--- doc/_templates/index.html	2009-08-18 00:10:19 +0000
+++ doc/en/_templates/index.html	2009-09-09 11:43:10 +0000
@@ -7,25 +7,39 @@
 
   <table class="contentstable" align="center" style="margin-left: 30px"><tr>
     <td width="50%">
-        <p class="biglink"><a class="biglink" href="{{ pathto("en/user-guide/index") }}">User Guide</a><br/>
+        <p class="biglink"><a class="biglink" href="{{ pathto("user-guide/index") }}">User Guide</a><br/>
         <span class="linkdescr">how to use Bazaar effectively</span>
       </p>
-      <p class="biglink"><a class="biglink" href="{{ pathto("en/tutorials/index") }}">Tutorials</a><br/>
+      <p class="biglink"><a class="biglink" href="{{ pathto("tutorials/index") }}">Tutorials</a><br/>
       <span class="linkdescr">brief introductions</span>
       </p>
-      <p class="biglink"><a class="biglink" href="{{ pathto("en/quick-reference/index") }}">Quick Reference</a><br/>
+      <p class="biglink"><a class="biglink" href="{{ pathto("quick-reference/index") }}">Quick Reference</a><br/>
       <span class="linkdescr">for your wall</span>
       </p>
-      <p class="biglink"><a class="biglink" href="{{ pathto("en/user-reference/bzr_man") }}">User Reference</a><br/>
-      <span class="linkdescr">all the gory details</span>
-      </p>
     </td><td width="50%">
-    <p class="biglink"><a class="biglink" href="{{ pathto("en/release-notes/NEWS") }}">Release Notes</a><br/>
+    <p class="biglink"><a class="biglink" href="{{ pathto("release-notes/index") }}">Release Notes</a><br/>
       <span class="linkdescr">what's new</span>
       </p>
-      <p class="biglink"><a class="biglink" href="{{ pathto("en/upgrade-guide/index") }}">Upgrade Guide</a><br/>
+      <p class="biglink"><a class="biglink" href="{{ pathto("upgrade-guide/index") }}">Upgrade Guide</a><br/>
       <span class="linkdescr">moving to Bazaar 2.x</span>
       </p>
+      <p class="biglink"><a class="biglink" href="{{ pathto("user-reference/index") }}">User Reference</a><br/>
+      <span class="linkdescr">all the gory details</span>
+      </p>
+    </td></tr>
+  </table>
+
+  <h2>Related links</h2>
+
+  <table class="contentstable" align="center" style="margin-left: 30px"><tr>
+    <td width="50%">
+        <p class="biglink"><a class="biglink" href="https://answers.launchpad.net/bzr">FAQ</a><br/>
+      <span class="linkdescr">frequently asked questions</span>
+      </p>
+      <p class="biglink"><a class="biglink" href="http://bazaar-vcs.org/BzrGlossary/">Glossary</a><br/>
+      <span class="linkdescr">help with terminology</span>
+      </p>
+    </td><td width="50%">
       <p class="biglink"><a class="biglink" href="http://doc.bazaar-vcs.org/migration/en/">Migration Docs</a><br/>
       <span class="linkdescr">for refugees of other tools</span>
       </p>
@@ -35,31 +49,7 @@
     </td></tr>
   </table>
 
-  <p>Keen to help? See the <a href="{{ pathto("developers/index") }}">Developer Docs</a>
+  <p>Keen to help? See the <a href="http://doc.bazaar-vcs.org/developers/">Developer Docs</a>
       for policies and tools on contributing code, tests and documentation.</p>
 
-
-  <h2>Related Links</h2>
-
-  <table class="contentstable" align="center" style="margin-left: 30px"><tr>
-    <td width="25%">
-        <p><a href="https://answers.launchpad.net/bzr">FAQ</a>
-        </p>
-    </td><td width="25%">
-        <p><a href="http://bazaar-vcs.org/BzrGlossary/">Glossary</a>
-        </p>
-    </td><td width="25%">
-        <p><a href="{{ pathto("genindex") }}">Index</a>
-        </p>
-    </td><td width="25%">
-        <p><a href="{{ pathto("search") }}">Search</a>
-        </p>
-    </td></tr>
-  </table>
-
-  <hr>
-  <p>Other languages:
-      <a href="{{ pathto("index.es") }}">Spanish</a>,
-      <a href="{{ pathto("index.ru") }}">Russian</a>
-  </p>
 {% endblock %}

=== modified file 'doc/en/_templates/layout.html'
--- doc/_templates/layout.html	2009-07-22 13:41:01 +0000
+++ doc/en/_templates/layout.html	2009-09-03 00:21:59 +0000
@@ -3,5 +3,6 @@
 {% block rootrellink %}
 <li><a href="http://bazaar-vcs.org/">
     <img src="{{ pathto("_static/bzr icon 16.png", 1) }}" /> Home</a>&nbsp;|&nbsp;</li>
+<a href="http://doc.bazaar-vcs.org/en/">Documentation</a>&nbsp;|&nbsp;</li>
 {{ super() }}
 {% endblock %}

=== renamed file 'doc/conf.py' => 'doc/en/conf.py'
--- doc/conf.py	2009-07-22 13:41:01 +0000
+++ doc/en/conf.py	2009-09-09 13:34:08 +0000
@@ -4,208 +4,86 @@
 # sphinx-quickstart on Tue Jul 21 17:04:52 2009.
 #
 # This file is execfile()d with the current directory set to its containing dir.
-#
-# Note that not all possible configuration values are present in this
-# autogenerated file.
-#
-# All configuration values have a default; values that are commented out
-# serve to show the default.
 
 import sys, os
 
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
-#sys.path.append(os.path.abspath('.'))
-
-# -- General configuration -----------------------------------------------------
-
-# Add any Sphinx extension module names here, as strings. They can be extensions
-# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.ifconfig']
-
-# Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
-
-# The suffix of source filenames.
-source_suffix = '.txt'
-
-# The encoding of source files.
-#source_encoding = 'utf-8'
-
-# The master toctree document.
-master_doc = 'contents'
-
-# General information about the project.
-project = u'Bazaar'
-copyright = u'2009, Canonical Ltd'
-
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-#
-# The short X.Y version.
-version = '1.18'
-# The full version, including alpha/beta/rc tags.
-release = '1.18dev'
-
-# The language for content autogenerated by Sphinx. Refer to documentation
-# for a list of supported languages.
-#language = None
-
-# There are two options for replacing |today|: either, you set today to some
-# non-false value, then it is used:
-#today = ''
-# Else, today_fmt is used as the format for a strftime call.
-#today_fmt = '%B %d, %Y'
-
-# List of documents that shouldn't be included in the build.
-#unused_docs = []
-
-# List of directories, relative to source directory, that shouldn't be searched
-# for source files.
-exclude_trees = ['_build']
-
-# The reST default role (used for this markup: `text`) to use for all documents.
-#default_role = None
-
-# If true, '()' will be appended to :func: etc. cross-reference text.
-#add_function_parentheses = True
-
-# If true, the current module name will be prepended to all description
-# unit titles (such as .. function::).
-#add_module_names = True
-
-# If true, sectionauthor and moduleauthor directives will be shown in the
-# output. They are ignored by default.
-#show_authors = False
-
-# The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
-
-# A list of ignored prefixes for module index sorting.
-#modindex_common_prefix = []
-
-
-# -- Options for HTML output ---------------------------------------------------
-
-# The theme to use for HTML and HTML Help pages.  Major themes that come with
-# Sphinx are currently 'default' and 'sphinxdoc'.
-html_theme = 'default'
-
-# Theme options are theme-specific and customize the look and feel of a theme
-# further.  For a list of options available for each theme, see the
-# documentation.
-html_theme_options = {
-    'rightsidebar': True,
-
-    # Non-document areas: header (relbar), footer, sidebar, etc.
-    # Some useful colours here:
-    # * blue: darkblue, mediumblue, darkslateblue, cornflowerblue, royalblue,
-    #   midnightblue
-    # * gray: dimgray, slategray, lightslategray
-    'sidebarbgcolor':   "cornflowerblue",
-    'sidebarlinkcolor': "midnightblue",
-    'relbarbgcolor':    "darkblue",
-    'footerbgcolor':    "lightslategray",
-
-    # Text, heading and code colouring
-    'codebgcolor':      "lightyellow",
-    'codetextcolor':    "firebrick",
-    'linkcolor':        "mediumblue",
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'en'
+
+# Translations & supporting helper function
+bzr_titles = {
+        u'Table of Contents (%s)': None,
+        u'Bazaar User Guide': None,
+        u'Bazaar User Reference': None,
+        u'Bazaar Release Notes': None,
+        u'Bazaar Upgrade Guide': None,
+        u'Bazaar in five minutes': None,
+        u'Bazaar Tutorial': None,
+        u'Using Bazaar With Launchpad': None,
+        u'Centralized Workflow Tutorial': None,
     }
-
-# Add any paths that contain custom themes here, relative to this directory.
-#html_theme_path = []
-
-# The name for this set of Sphinx documents.  If None, it defaults to
-# "<project> v<release> documentation".
-#html_title = None
+def bzr_title(s):
+    return bzr_titles.get(s) or s
 
 # A shorter title for the navigation bar.  Default is the same as html_title.
-#html_short_title = None
-
-# The name of an image file (relative to this directory) to place at the top
-# of the sidebar.
-#html_logo = None
-
-# The name of an image file (within the static path) to use as favicon of the
-# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
-# pixels large.
-html_favicon = "bzr.ico"
-
-# Add any paths that contain custom static files (such as style sheets) here,
-# relative to this directory. They are copied after the builtin static files,
-# so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
-
-# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
-# using the given strftime format.
-#html_last_updated_fmt = '%b %d, %Y'
-
-# If true, SmartyPants will be used to convert quotes and dashes to
-# typographically correct entities.
-#html_use_smartypants = True
-
-# Custom sidebar templates, maps document names to template names.
-#html_sidebars = {}
+html_short_title = bzr_title(u"Table of Contents (%s)") % (release,)
 
 # Additional templates that should be rendered to pages, maps page names to
 # template names.
-html_additional_pages = {'contents': 'index.html'}
-
-# If false, no module index is generated.
-#html_use_modindex = True
-
-# If false, no index is generated.
-#html_use_index = True
-
-# If true, the index is split into individual pages for each letter.
-#html_split_index = False
-
-# If true, links to the reST sources are added to the pages.
-html_show_sourcelink = True
-
-# If true, an OpenSearch description file will be output, and all pages will
-# contain a <link> tag referring to it.  The value of this option must be the
-# base URL from which the finished HTML is served.
-#html_use_opensearch = ''
-
-# If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
-#html_file_suffix = ''
+html_additional_pages = {'index': 'index.html'}
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = 'Bazaardoc'
-
-
-# -- Options for LaTeX output --------------------------------------------------
-
-# The paper size ('letter' or 'a4').
-#latex_paper_size = 'letter'
-
-# The font size ('10pt', '11pt' or '12pt').
-#latex_font_size = '10pt'
+htmlhelp_basename = 'bzr-%s' % (bzr_locale,)
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass [howto/manual]).
 latex_documents = [
-  ('contents', 'Bazaar.tex', u'Bazaar Documentation',
-   u'Bazaar Developers', 'manual'),
-]
-
-# The name of an image file (relative to this directory) to place at the top of
-# the title page.
-#latex_logo = None
-
-# For "manual" documents, if this is true, then toplevel headings are parts,
-# not chapters.
-#latex_use_parts = False
-
-# Additional stuff for the LaTeX preamble.
-#latex_preamble = ''
-
-# Documents to append as an appendix to all manuals.
-#latex_appendices = []
-
-# If false, no module index is generated.
-#latex_use_modindex = True
+  # Manuals
+  ('user-guide/index', 'bzr-%s-user-guide.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar User Guide'), bzr_team, 'manual'),
+  ('user-reference/bzr_man', 'bzr-%s-user-reference.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar User Reference'), bzr_team, 'manual'),
+  ('release-notes/NEWS', 'bzr-%s-release-notes.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar Release Notes'), bzr_team, 'manual'),
+  ('upgrade-guide/index', 'bzr-%s-upgrade-guide.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar Upgrade Guide'), bzr_team, 'manual'),
+  # Tutorials
+  ('mini-tutorial/index', 'bzr-%s-tutorial-mini.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar in five minutes'), bzr_team, 'howto'),
+  ('tutorials/tutorial', 'bzr-%s-tutorial.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar Tutorial'), bzr_team, 'howto'),
+  ('tutorials/using_bazaar_with_launchpad',
+    'bzr-%s-tutorial-with-launchpad.tex' % (bzr_locale,),
+    bzr_title(u'Using Bazaar With Launchpad'), bzr_team, 'howto'),
+  ('tutorials/centralized_workflow',
+    'bzr-%s-tutorial-centralized.tex' % (bzr_locale,),
+    bzr_title(u'Centralized Workflow Tutorial'), bzr_team, 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+unused_docs = [
+    # Placeholder for later
+    'admin-guide/index',
+    # Subtopics that get included
+    'upgrade-guide/overview',
+    'upgrade-guide/data_migration',
+    'upgrade-guide/tips_and_tricks',
+    # Plain-style documentation generation stuff
+    'release-notes/NEWS',
+    'user-reference/bzr_man',
+    'user-guide/index-plain',
+    # Miscellaneous
+    'user-reference/readme',
+]
+

=== removed directory 'doc/en/developer-guide'
=== renamed file 'doc/contents.txt' => 'doc/en/index.txt'
--- doc/contents.txt	2009-08-18 00:10:19 +0000
+++ doc/en/index.txt	2009-09-09 11:43:10 +0000
@@ -4,39 +4,15 @@
    contain the root `toctree` directive.
 
 
-Core documentation
-==================
-
-.. toctree::
-   :maxdepth: 1
-
-   en/user-guide/index
-   en/tutorials/index
-   en/quick-reference/index
-   en/user-reference/index
-
-.. toctree::
-   :maxdepth: 1
-
-   en/release-notes/index
-   en/upgrade-guide/index
-   developers/index
-
-
-Other languages:
-
-.. toctree::
-   :maxdepth: 1
-
-   index.es
-   index.ru
-
-
-Related links
-=============
-
-* `Frequently Asked Questions <http://bazaar-vcs.org/FAQ>`_
-* `Glossary <http://bazaar-vcs.org/BzrGlossary>`_
-* :ref:`genindex`
-* :ref:`search`
-
+Table of Contents
+=================
+
+.. toctree::
+   :maxdepth: 1
+
+   user-guide/index
+   tutorials/index
+   quick-reference/index
+   release-notes/index
+   upgrade-guide/index
+   user-reference/index

=== renamed file 'doc/make.bat' => 'doc/en/make.bat'
=== modified file 'doc/en/mini-tutorial/index.txt'
--- doc/en/mini-tutorial/index.txt	2009-04-04 02:50:01 +0000
+++ doc/en/mini-tutorial/index.txt	2009-09-02 16:03:51 +0000
@@ -2,8 +2,6 @@
 Bazaar in five minutes
 ======================
 
-.. contents::
-
 Introduction
 ============
 

=== modified file 'doc/en/quick-reference/index.txt'
--- doc/en/quick-reference/index.txt	2009-07-22 14:07:56 +0000
+++ doc/en/quick-reference/index.txt	2009-09-09 02:32:10 +0000
@@ -1,6 +1,6 @@
 Quick Reference
 ===============
 
-* `SVG format <../../_static/en/quick-reference/bzr-quick-reference.svg>`_
-* `PDF format <../../_static/en/quick-reference/bzr-quick-reference.pdf>`_
-* `PNG format <../../_static/en/quick-reference/bzr-quick-reference.png>`_
+* `PDF format <../_static/en/bzr-en-quick-reference.pdf>`_
+* `PNG format <../_static/en/bzr-en-quick-reference.png>`_
+* `SVG format <../_static/en/bzr-en-quick-reference.svg>`_

=== modified file 'doc/en/tutorials/centralized_workflow.txt'
--- doc/en/tutorials/centralized_workflow.txt	2009-07-22 13:41:01 +0000
+++ doc/en/tutorials/centralized_workflow.txt	2009-09-02 16:03:51 +0000
@@ -1,6 +1,6 @@
-====================
-Centralized Workflow
-====================
+=============================
+Centralized Workflow Tutorial
+=============================
 
 
 Overview
@@ -23,8 +23,6 @@
 
 .. _Bazaar: http://bazaar-vcs.org
 
-.. contents::
-
 
 Initial Setup
 =============

=== modified file 'doc/en/tutorials/tutorial.txt'
--- doc/en/tutorials/tutorial.txt	2009-06-27 08:10:13 +0000
+++ doc/en/tutorials/tutorial.txt	2009-09-02 16:03:51 +0000
@@ -11,8 +11,6 @@
 Bazaar Tutorial
 ===============
 
-Current for bzr-0.91, 2007-08
-
 
 Introduction
 ============
@@ -24,8 +22,8 @@
 different." Otherwise, get some coffee or tea, get comfortable and get
 ready to catch up. 
 
-The Purposes of Revision Control
-================================
+The purpose of revision control
+===============================
 
 Odds are that you have worked on some sort of textual data -- the sources
 to a program, web sites or the config files that Unix system
@@ -57,8 +55,8 @@
 We keep these logs so that if later there is some sort of problem with
 sftp, we can figure out when the problem probably happened. 
 
-How DRCS is Different
----------------------
+How DRCS is different
+=====================
 
 Many Revision Control Systems (RCS) are stored on servers. If one wants to
 work on the code stored within an RCS, then one needs to connect to the
@@ -282,6 +280,7 @@
 As a shortcut, ``bzr diff -p1`` produces a form that works with the 
 command ``patch -p1``.
 
+
 Committing changes
 ==================
 
@@ -308,7 +307,7 @@
 can also be useful when you pick up your work after a break.)
 
 Message from an editor
-======================
+----------------------
 
 If you use neither the ``-m`` nor the ``-F`` option then bzr will open an
 editor for you to enter a message.  The editor to run is controlled by
@@ -355,9 +354,13 @@
 given then only those ones will be affected. ``bzr revert`` also clears the
 list of pending merges revisions.
 
+
 Ignoring files
 ==============
 
+The .bzrignore file
+-------------------
+
 Many source trees contain some files that do not need to be versioned,
 such as editor backups, object or bytecode files, and built programs.  You
 can simply not add them, but then they'll always crop up as unknown files.
@@ -400,7 +403,7 @@
     % bzr commit -m "Add ignore patterns"
 
 
-Global Ignores
+Global ignores
 --------------
 
 There are some ignored files which are not project specific, but more user
@@ -574,6 +577,7 @@
   rsync, or other related file transfer methods.  This is usually less safe
   than using ``push``, but may be faster or easier in some situations.
 
+
 Moving changes between trees 
 ============================
 

=== modified file 'doc/en/tutorials/using_bazaar_with_launchpad.txt'
--- doc/en/tutorials/using_bazaar_with_launchpad.txt	2009-07-22 13:41:01 +0000
+++ doc/en/tutorials/using_bazaar_with_launchpad.txt	2009-09-02 16:03:51 +0000
@@ -2,8 +2,6 @@
 Using Bazaar with Launchpad
 ===========================
 
-.. contents::
-
 
 Motivation
 ==========

=== modified file 'doc/en/upgrade-guide/data_migration.txt'
--- doc/en/upgrade-guide/data_migration.txt	2009-07-03 05:22:27 +0000
+++ doc/en/upgrade-guide/data_migration.txt	2009-09-09 13:34:08 +0000
@@ -34,7 +34,7 @@
 
 For detailed help on these commands, see the `Bazaar User Reference`_.
 
-.. _Bazaar User Reference: ../user-reference/bzr_man.html
+.. _Bazaar User Reference: ../user-reference/index.html
 
 
 Communicating with your community

=== modified file 'doc/en/upgrade-guide/index.txt'
--- doc/en/upgrade-guide/index.txt	2009-07-22 13:41:01 +0000
+++ doc/en/upgrade-guide/index.txt	2009-09-02 16:03:51 +0000
@@ -8,8 +8,6 @@
 ..   level 3 ~~~~~~~~
 ..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
 
-.. contents::
-
 .. include:: overview.txt
 .. include:: data_migration.txt
 .. include:: tips_and_tricks.txt

=== modified file 'doc/en/user-guide/branching_a_project.txt'
--- doc/en/user-guide/branching_a_project.txt	2009-02-26 11:28:50 +0000
+++ doc/en/user-guide/branching_a_project.txt	2009-09-09 15:30:59 +0000
@@ -37,9 +37,10 @@
 where to put it on your filesystem. For maximum storage
 efficiency down the track, it is recommended that branches
 be created somewhere under a directory that has been set up
-as a shared repository. (See `Feature branches`_ in
-n `Organizing your workspace`_ for a commonly used layout.)
-For example::
+as a shared repository. (See `Feature branches
+<organizing_your_workspace.html#feature-branches>`_ in
+`Organizing your workspace <organizing_your_workspace.html>`_
+for a commonly used layout.) For example::
 
   bzr init-repo my-repo
   cd my-repo
@@ -91,7 +92,7 @@
 the latest version.
 
 As explained in later chapters, Bazaar also has support for
-`lightweight checkouts <#getting-a-lightweight-checkout>`_ 
+`lightweight checkouts <using_checkouts.html#getting-a-lightweight-checkout>`_ 
 of a branch, i.e. working trees with
 no local storage of history. Of course, disconnected usage
 is not available then but that's a tradeoff you can decide

=== modified file 'doc/en/user-guide/browsing_history.txt'
--- doc/en/user-guide/browsing_history.txt	2009-03-26 12:57:41 +0000
+++ doc/en/user-guide/browsing_history.txt	2009-09-09 15:06:00 +0000
@@ -87,7 +87,7 @@
 
 History browsing is one area where GUI tools really make life easier.
 Bazaar has numerous plug-ins that provide this capability including
-QBzr and bzr-gtk. See `Using plugins`_ for details on how to install
+QBzr and bzr-gtk. See `Using plugins <plugins.html>`_ for details on how to install
 these if they are not already installed.
 
 To use the graphical viewer from QBzr::

=== modified file 'doc/en/user-guide/core_concepts.txt'
--- doc/en/user-guide/core_concepts.txt	2008-10-16 10:57:16 +0000
+++ doc/en/user-guide/core_concepts.txt	2009-09-09 15:06:00 +0000
@@ -50,9 +50,10 @@
 depend on which revision is the tip (i.e. most recent revision)
 in the branch.
 
-See `Specifying revisions`_ in the appendices for a closer look at
-the numerous ways that revisions and ranges of revisions can be specified
-in Bazaar, and `Understanding Revision Numbers`_ for a more detailed
+See `Specifying revisions <specifying_revisions.html>`_ in the appendices
+for a closer look at the numerous ways that revisions and ranges of
+revisions can be specified in Bazaar, and `Understanding Revision Numbers
+<zen.html#understanding-revision-numbers>`_ for a more detailed
 description of revision numbering.
 
 .. *TODO: add diagram*
@@ -108,15 +109,15 @@
 to use a *standalone tree*, which has a working tree, branch, and repository
 all in a single location. Other common scenarios include:
 
-* `Shared repositories <#a-reminder-about-shared-repositories>`_ - working
-  tree and branch are colocated, but the repository is in a higher level
+* `Shared repositories <branching_a_project.html#a-reminder-about-shared-repositories>`_
+  - working tree and branch are colocated, but the repository is in a higher level
   directory.
 
-* `Stacked branches <#using-stacked-branches>`_ - branch stores just its
+* `Stacked branches <stacked.html>`_ - branch stores just its
   unique revisions, using its parent's repository for common revisions.
 
-* `Lightweight checkouts <#getting-a-lightweight-checkout>`_ - branch is 
-  stored in a different location to the working tree.
+* `Lightweight checkouts <using_checkouts.html#getting-a-lightweight-checkout>`_
+  - branch is stored in a different location to the working tree.
 
 The best way to use Bazaar, however, depends on your needs. Let's take a
 look at some common workflows next.

=== added file 'doc/en/user-guide/index-plain.txt'
--- doc/en/user-guide/index-plain.txt	1970-01-01 00:00:00 +0000
+++ doc/en/user-guide/index-plain.txt	2009-09-09 12:57:43 +0000
@@ -0,0 +1,119 @@
+#################
+Bazaar User Guide
+#################
+
+.. Please mark sections in included files as following:
+..   level 1 ========
+..   level 2 --------
+..   level 3 ~~~~~~~~
+..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
+
+.. contents:: :depth: 3
+
+
+Introduction
+############
+
+.. include:: introducing_bazaar.txt
+.. include:: core_concepts.txt
+.. include:: bazaar_workflows.txt
+
+
+Getting started
+###############
+
+.. include:: installing_bazaar.txt
+.. include:: entering_commands.txt
+.. include:: getting_help.txt
+.. include:: configuring_bazaar.txt
+.. include:: using_aliases.txt
+.. include:: plugins.txt
+.. include:: zen.txt
+
+
+Personal version control
+########################
+
+.. include:: solo_intro.txt
+.. include:: starting_a_project.txt
+.. include:: controlling_registration.txt
+.. include:: reviewing_changes.txt
+.. include:: recording_changes.txt
+.. include:: browsing_history.txt
+.. include:: releasing_a_project.txt
+.. include:: undoing_mistakes.txt
+
+
+Sharing with peers
+##################
+
+.. include:: partner_intro.txt
+.. include:: branching_a_project.txt
+.. include:: merging_changes.txt
+.. include:: resolving_conflicts.txt
+.. include:: annotating_changes.txt
+
+
+Team collaboration, central style
+#################################
+
+.. include:: central_intro.txt
+.. include:: publishing_a_branch.txt
+.. include:: using_checkouts.txt
+.. include:: working_offline_central.txt
+.. include:: reusing_a_checkout.txt
+
+
+Team collaboration, distributed style
+#####################################
+
+.. include:: distributed_intro.txt
+.. include:: organizing_branches.txt
+.. include:: using_gatekeepers.txt
+.. include:: sending_changes.txt
+
+
+Miscellaneous topics
+####################
+
+.. include:: part2_intro.txt
+.. include:: adv_merging.txt
+.. include:: shelving_changes.txt
+.. include:: filtered_views.txt
+.. include:: stacked.txt
+.. include:: server.txt
+.. include:: hooks.txt
+.. include:: version_info.txt
+ 
+
+A brief tour of some popular plugins
+####################################
+
+.. include:: bzrtools_plugin.txt
+.. include:: svn_plugin.txt
+.. include later looms_plugin.txt
+
+
+Integrating Bazaar into your environment
+########################################
+
+.. include:: web_browsing.txt
+.. include later - file_explorers.txt
+.. include later - desktop_integration.txt
+.. include later - editors_and_ides.txt
+.. include later - email.txt
+.. include:: bug_trackers.txt
+
+
+Appendices
+##########
+
+.. include:: specifying_revisions.txt
+.. include:: organizing_your_workspace.txt
+.. include:: shared_repository_layouts.txt
+.. include:: setting_up_email.txt
+.. include:: http_smart_server.txt
+.. include:: writing_a_plugin.txt
+
+.. |--| unicode:: U+2014
+

=== removed file 'doc/en/user-guide/index.txt'
--- doc/en/user-guide/index.txt	2009-07-26 15:58:33 +0000
+++ doc/en/user-guide/index.txt	1970-01-01 00:00:00 +0000
@@ -1,118 +0,0 @@
-#################
-Bazaar User Guide
-#################
-
-.. Please mark sections in included files as following:
-..   level 1 ========
-..   level 2 --------
-..   level 3 ~~~~~~~~
-..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
-
-.. contents:: :depth: 3
-
-
-Introduction
-############
-
-.. include:: introducing_bazaar.txt
-.. include:: core_concepts.txt
-.. include:: bazaar_workflows.txt
-
-
-Getting started
-###############
-
-.. include:: installing_bazaar.txt
-.. include:: entering_commands.txt
-.. include:: getting_help.txt
-.. include:: configuring_bazaar.txt
-.. include:: using_aliases.txt
-.. include:: plugins.txt
-.. include:: zen.txt
-
-
-Personal version control
-########################
-
-.. include:: solo_intro.txt
-.. include:: starting_a_project.txt
-.. include:: controlling_registration.txt
-.. include:: reviewing_changes.txt
-.. include:: recording_changes.txt
-.. include:: browsing_history.txt
-.. include:: releasing_a_project.txt
-.. include:: undoing_mistakes.txt
-
-
-Sharing with peers
-##################
-
-.. include:: partner_intro.txt
-.. include:: branching_a_project.txt
-.. include:: merging_changes.txt
-.. include:: resolving_conflicts.txt
-.. include:: annotating_changes.txt
-
-
-Team collaboration, central style
-#################################
-
-.. include:: central_intro.txt
-.. include:: publishing_a_branch.txt
-.. include:: using_checkouts.txt
-.. include:: working_offline_central.txt
-.. include:: reusing_a_checkout.txt
-
-
-Team collaboration, distributed style
-#####################################
-
-.. include:: distributed_intro.txt
-.. include:: organizing_branches.txt
-.. include:: using_gatekeepers.txt
-.. include:: sending_changes.txt
-
-
-Miscellaneous topics
-####################
-
-.. include:: part2_intro.txt
-.. include:: adv_merging.txt
-.. include:: shelving_changes.txt
-.. include:: filtered_views.txt
-.. include:: stacked.txt
-.. include:: server.txt
-.. include:: hooks.txt
-.. include:: version_info.txt
- 
-
-A brief tour of some popular plugins
-####################################
-
-.. include:: bzrtools_plugin.txt
-.. include:: svn_plugin.txt
-.. include later looms_plugin.txt
-
-
-Integrating Bazaar into your environment
-########################################
-
-.. include:: web_browsing.txt
-.. include later - file_explorers.txt
-.. include later - desktop_integration.txt
-.. include later - editors_and_ides.txt
-.. include later - email.txt
-.. include:: bug_trackers.txt
-
-
-Appendices
-##########
-
-.. include:: specifying_revisions.txt
-.. include:: organizing_your_workspace.txt
-.. include:: shared_repository_layouts.txt
-.. include:: setting_up_email.txt
-.. include:: http_smart_server.txt
-.. include:: writing_a_plugin.txt
-
-.. |--| unicode:: U+2014

=== renamed file 'doc/en/user-guide/index-for-2x.txt' => 'doc/en/user-guide/index.txt'
=== modified file 'doc/en/user-guide/installing_bazaar.txt'
--- doc/en/user-guide/installing_bazaar.txt	2009-05-01 03:35:18 +0000
+++ doc/en/user-guide/installing_bazaar.txt	2009-09-09 15:08:17 +0000
@@ -85,9 +85,9 @@
 
   2. Get a copy of the development version like this::
 
-       bzr branch http://bazaar-vcs.org/bzr/bzr.dev
+       bzr branch lp:bzr
 
-  3. Put the created directory (bzr.dev) on your PATH.
+  3. Put the created directory on your PATH.
 
 Advanced users may also wish to build the optional C extensions for greater
 speed. This can be done using ``make`` and requires ``pyrex`` and a C compiler.

=== modified file 'doc/en/user-guide/merging_changes.txt'
--- doc/en/user-guide/merging_changes.txt	2007-12-04 12:56:31 +0000
+++ doc/en/user-guide/merging_changes.txt	2009-09-09 15:06:00 +0000
@@ -53,7 +53,7 @@
 
 Note that some merges can only be completed with the assistance
 of a human. Details on how to resolve these are given in
-`Resolving conflicts`_.
+`Resolving conflicts <resolving_conflicts.html>`_.
 
 Recording a merge
 -----------------

=== modified file 'doc/en/user-guide/organizing_your_workspace.txt'
--- doc/en/user-guide/organizing_your_workspace.txt	2009-02-26 11:28:50 +0000
+++ doc/en/user-guide/organizing_your_workspace.txt	2009-09-09 15:30:59 +0000
@@ -172,5 +172,5 @@
 ----------------
 
 If you wish, you can put together your own layout based on how **you** like
-things organized. See `Advanced shared repository layouts`_ for examples
-and inspiration.
+things organized. See `Advanced shared repository layouts
+<shared_repository_layouts.html>`_ for examples and inspiration.

=== modified file 'doc/en/user-guide/plugins.txt'
--- doc/en/user-guide/plugins.txt	2009-08-20 13:26:36 +0000
+++ doc/en/user-guide/plugins.txt	2009-09-11 07:55:48 +0000
@@ -94,4 +94,5 @@
   ================ ================= ==================================
 
 If you wish to write your own plugins, it is not difficult to do.
-See `Writing a plugin`_ in the appendices to get started.
+See `Writing a plugin <writing a plugin.html>`_ in the appendices to get
+started.

=== modified file 'doc/en/user-guide/publishing_a_branch.txt'
--- doc/en/user-guide/publishing_a_branch.txt	2009-02-26 11:28:50 +0000
+++ doc/en/user-guide/publishing_a_branch.txt	2009-09-09 15:06:00 +0000
@@ -19,8 +19,8 @@
 You can think of this step as similar to setting up a new cvsroot or
 Subversion repository. However, Bazaar gives you more flexibility
 in how branches may be organised in your repository. See
-`Advanced shared repository layouts`_ in the appendices for
-guidelines and examples.
+`Advanced shared repository layouts <shared_repository_layouts.html>`_
+in the appendices for guidelines and examples.
 
 
 Starting a central branch

=== modified file 'doc/en/user-guide/undoing_mistakes.txt'
--- doc/en/user-guide/undoing_mistakes.txt	2009-04-04 02:50:01 +0000
+++ doc/en/user-guide/undoing_mistakes.txt	2009-09-09 15:06:00 +0000
@@ -97,8 +97,9 @@
 chapter, it is worth noting now that ``uncommit`` restores any pending
 merges. (Running ``bzr status`` after ``uncommit`` will show these.)
 ``merge`` can also be used to effectively undo just a selected commit
-earlier in history. For more information on ``merge``, see `Merging changes`_
-in the next chapter and the Bazaar User Reference.
+earlier in history. For more information on ``merge``, see
+`Merging changes <merging_changes.html>`_ in the next chapter and the
+Bazaar User Reference.
 
 Undoing multiple commits
 ------------------------
@@ -132,7 +133,8 @@
 This will change your entire tree back to the state as of revision 19,
 which is probably only what you want if you haven't made any new commits
 since then. If you have, the ``revert`` would wipe them out as well. In that
-case, you probably want to use `Reverse cherrypicking`_ instead to
+case, you probably want to use `Reverse cherrypicking
+<advanced_merging.html#reverse-cherrypicking>`_ instead to
 back out the bad fix.
 
 Note: As an alternative to using an absolute revision number (like 19), you can

=== modified file 'doc/en/user-guide/using_checkouts.txt'
--- doc/en/user-guide/using_checkouts.txt	2008-12-24 03:14:16 +0000
+++ doc/en/user-guide/using_checkouts.txt	2009-09-09 15:30:59 +0000
@@ -66,8 +66,9 @@
 Note: If your code base is really large and disk space on your computer
 is limited, lightweight checkouts may be the right choice for you.
 Be sure to consider all your options though including
-`shared repositories <#a-reminder-about-shared-repositories>`_,
-`stacked branches <#using-stacked-branches>`_, and `reusing a checkout`_.
+`shared repositories <branching_a_project.html#a-reminder-about-shared-repositories>`_,
+`stacked branches <stacked.html>`_, and
+`reusing a checkout <reusing_a_checkout.html>`_.
 
 Updating to the latest content
 ------------------------------

=== added directory 'doc/es/_static'
=== added file 'doc/es/_static/bzr icon 16.png'
Binary files doc/es/_static/bzr icon 16.png and doc/es/_static/bzr icon 16.png differ
=== added file 'doc/es/_static/bzr.ico'
Binary files doc/es/_static/bzr.ico and doc/es/_static/bzr.ico differ
=== added directory 'doc/es/_static/es'
=== renamed file 'doc/es/quick-reference/Makefile' => 'doc/es/_static/es/Makefile'
--- doc/es/quick-reference/Makefile	2009-06-29 11:02:31 +0000
+++ doc/es/_static/es/Makefile	2009-09-09 00:49:50 +0000
@@ -1,5 +1,5 @@
-TARGETS=quick-start-summary.png quick-start-summary.pdf
-OBJECTS=quick-start-summary.svg Makefile
+TARGETS=bzr-es-quick-reference.png bzr-es-quick-reference.pdf
+OBJECTS=bzr-es-quick-reference.svg Makefile
 
 all: $(TARGETS)
 
@@ -11,9 +11,9 @@
 .svg.png:
 	rsvg-convert -d 300 -p 300 -z 3.3346 -f png -o $@ $<
 
-bzr-quickref.png: $(OBJECTS)
+bzr-es-quick-reference.png: $(OBJECTS)
 
-bzr-quickref.pdf: $(OBJECTS)
+bzr-es-quick-reference.pdf: $(OBJECTS)
 
 clean:
 	rm -f $(TARGETS)

=== renamed file 'doc/es/quick-reference/quick-start-summary.pdf' => 'doc/es/_static/es/bzr-es-quick-reference.pdf'
=== renamed file 'doc/es/quick-reference/quick-start-summary.png' => 'doc/es/_static/es/bzr-es-quick-reference.png'
=== renamed file 'doc/es/quick-reference/quick-start-summary.svg' => 'doc/es/_static/es/bzr-es-quick-reference.svg'
=== added directory 'doc/es/_templates'
=== added file 'doc/es/_templates/layout.html'
--- doc/es/_templates/layout.html	1970-01-01 00:00:00 +0000
+++ doc/es/_templates/layout.html	2009-09-07 06:12:15 +0000
@@ -0,0 +1,8 @@
+{% extends "!layout.html" %}
+
+{% block rootrellink %}
+<li><a href="http://bazaar-vcs.org/">
+    <img src="{{ pathto("_static/bzr icon 16.png", 1) }}" /> Inicio</a>&nbsp;|&nbsp;</li>
+<a href="http://doc.bazaar-vcs.org/en/">Documentación</a>&nbsp;|&nbsp;</li>
+{{ super() }}
+{% endblock %}

=== added file 'doc/es/conf.py'
--- doc/es/conf.py	1970-01-01 00:00:00 +0000
+++ doc/es/conf.py	2009-09-09 15:51:18 +0000
@@ -0,0 +1,89 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# This file is execfile()d with the current directory set to its containing dir.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'es'
+
+# Translations & supporting helper function
+bzr_titles = {
+        u'Table of Contents (%s)': u'Contenidos (%s)',
+        u'Bazaar User Guide': u'Guia de Usuario',
+        u'Bazaar User Reference': None,
+        u'Bazaar Release Notes': None,
+        u'Bazaar Upgrade Guide': None,
+        u'Bazaar in five minutes': u'Bazaar en cinco minutos',
+        u'Bazaar Tutorial': None,
+        u'Using Bazaar With Launchpad': None,
+        u'Centralized Workflow Tutorial': None,
+    }
+def bzr_title(s):
+    return bzr_titles.get(s) or s
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+language = bzr_locale
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+html_short_title = bzr_title(u"Table of Contents (%s)") % (release,)
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {'index': 'index.html'}
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-%s' % (bzr_locale,)
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = [
+  # Manuals
+  ('user-guide/index', 'bzr-%s-user-guide.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar User Guide'), bzr_team, 'manual'),
+  #('user-reference/bzr_man', 'bzr-%s-user-reference.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar User Reference'), bzr_team, 'manual'),
+  #('release-notes/NEWS', 'bzr-%s-release-notes.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Release Notes'), bzr_team, 'manual'),
+  #('upgrade-guide/index', 'bzr-%s-upgrade-guide.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Upgrade Guide'), bzr_team, 'manual'),
+  # Tutorials
+  ('mini-tutorial/index', 'bzr-%s-tutorial-mini.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar in five minutes'), bzr_team, 'howto'),
+  #('tutorials/tutorial', 'bzr-%s-tutorial.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Tutorial'), bzr_team, 'howto'),
+  #('tutorials/using_bazaar_with_launchpad',
+  #  'bzr-%s-tutorial-with-launchpad.tex' % (bzr_locale,),
+  #  bzr_title(u'Using Bazaar With Launchpad'), bzr_team, 'howto'),
+  #('tutorials/centralized_workflow',
+  #  'bzr-%s-tutorial-centralized.tex' % (bzr_locale,),
+  #  bzr_title(u'Centralized Workflow Tutorial'), bzr_team, 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+unused_docs = [
+    # Subtopics that get included
+    'upgrade-guide/overview',
+    'upgrade-guide/data_migration',
+    'upgrade-guide/tips_and_tricks',
+    'user-guide/resolving_conflicts',
+    'user-guide/version_info',
+    # Plain-style documentation generation stuff
+    'user-guide/index-plain',
+]
+

=== removed directory 'doc/es/developer-guide'
=== renamed file 'doc/index.es.txt' => 'doc/es/index.txt'
--- doc/index.es.txt	2009-06-29 11:02:31 +0000
+++ doc/es/index.txt	2009-09-09 02:30:32 +0000
@@ -1,46 +1,40 @@
-==================================
+=================================
 Indice de Documentacion de Bazaar
-==================================
+=================================
 
 Las ultimas versiones de estos documentos se encuentran disponibles
-en la pagina de  Bazaar, http://doc.bazaar-vcs.org.
+en la pagina de  Bazaar, http://doc.bazaar-vcs.org/en/.
 
 Documentacion Principal
 =======================
 
-* `Mini Tutorial <es/mini-tutorial/index.html>`_ 
-
-* `Referencia Rapida <es/quick-reference/quick-start-summary.svg>`_
-
-* `Guia de Usuario <es/user-guide/index.html>`_ 
-
-* `Referencia <es/user-reference/bzr_man.html>`_ 
-
-* `Notas sobre la Version <es/release-notes/NEWS.html>`_
-
-* `Guia del Desarrollador <es/developer-guide/HACKING.html>`_
+.. toctree::
+   :maxdepth: 1
+
+   mini-tutorial/index
+   quick-reference/index
+   user-guide/index
 
 
 Otra Documentacion
-===================
+==================
 
 Mudandose a Bazaar (enlances web):
 
-* `Guias de Mudanzas <http://bazaar-vcs.org/BzrSwitching>`_ 
-  - para los usuarios que se mudan de otros SCV
-
-* `Guias de Migracion <http://bazaar-vcs.org/BzrMigration>`_
+* `Guias de Migracion <http://doc.bazaar-vcs.org/migration/en/>`_
   - para equipos que mudan el historial de otros SCV
 
+* `Guias de Plugins <http://doc.bazaar-vcs.org/plugins/en/>`_ 
+
 Otros Documentos (enlances web):
 
 * `Glosario <http://bazaar-vcs.org/BzrGlossary>`_
 
-* `Preguntas Frecuentes <http://bazaar-vcs.org/FAQ>`_
+* `Preguntas Frecuentes <https://answers.launchpad.net/bzr>`_
 
 * `Referencia del API bzrlib <http://bazaar-vcs.org/BzrLib>`_
 
 Especificaciones tecnicas, planes a futuro y varias
 notas tecnicas varias en Ingles:
 
-* `Catalogo de Documentos para Desarrolladores <developers/index.html>`_
+* `Catalogo de Documentos para Desarrolladores <http://doc.bazaar-vcs.org/latest/developers/>`_

=== modified file 'doc/es/mini-tutorial/index.txt'
--- doc/es/mini-tutorial/index.txt	2009-06-29 11:02:31 +0000
+++ doc/es/mini-tutorial/index.txt	2009-09-08 01:19:48 +0000
@@ -2,8 +2,6 @@
 Bazaar en cinco minutos
 =======================
 
-.. contents:: Contenidos
-
 Introducción
 ============
 

=== added file 'doc/es/quick-reference/index.txt'
--- doc/es/quick-reference/index.txt	1970-01-01 00:00:00 +0000
+++ doc/es/quick-reference/index.txt	2009-09-09 02:32:10 +0000
@@ -0,0 +1,6 @@
+Referencia Rapida
+=================
+
+* `PDF format <../_static/es/bzr-es-quick-reference.pdf>`_
+* `PNG format <../_static/es/bzr-es-quick-reference.png>`_
+* `SVG format <../_static/es/bzr-es-quick-reference.svg>`_

=== removed directory 'doc/es/release-notes'
=== added file 'doc/es/user-guide/index-plain.txt'
--- doc/es/user-guide/index-plain.txt	1970-01-01 00:00:00 +0000
+++ doc/es/user-guide/index-plain.txt	2009-09-09 12:57:43 +0000
@@ -0,0 +1,114 @@
+##########################
+Guia de Usuarios de Bazaar
+##########################
+
+.. Files are currently links but will become includes once the
+.. content makes more sense as a whole.
+.. Please mark sections in linked/included files as following:
+..   level 1 ========
+..   level 2 --------
+..   level 3 ~~~~~~~~
+..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
+
+
+Introducción
+############
+
+.. include later - introducing_bazaar.txt
+.. include later - core_concepts.txt
+.. include later - bazaar_workflows.txt
+
+
+Empezando
+#########
+
+.. include later - installing_bazaar.txt
+.. include later -  entering_commands.txt
+.. include later - revnos.txt
+.. include later - getting_help.txt
+.. include later - configuring_bazaar.txt
+.. include later - using_aliases.txt
+.. include later - plugins.txt
+
+
+Control de Versionamiento Personal
+##################################
+
+.. include later - solo_intro.txt
+.. include later - starting_a_project.txt
+.. include later - controlling_registration.txt
+.. include later - reviewing_changes.txt
+.. include later - recording_changes.txt
+.. include later - browsing_history.txt
+.. include later - releasing_a_project.txt
+.. include later - undoing_mistakes.txt
+
+
+Compartiendo con tus pares
+##########################
+
+.. include later - partner_intro.txt
+.. include later - branching_a_project.txt
+.. include later - merging_changes.txt
+.. include:: resolving_conflicts.txt
+.. include later - annotating_changes.txt
+
+
+Colaboración en equipo, modo centralizado
+#########################################
+
+.. include later - central_intro.txt
+.. include later - publishing_a_branch.txt
+.. include later - using_checkouts.txt
+.. include later - working_offline_central.txt
+.. include later - reusing_a_checkout.txt
+
+
+Colaboracion en equipo, modo distribuido
+########################################
+
+.. include later - distributed_intro.txt
+.. include later - organizing_branches.txt
+.. include later - using_gatekeepers.txt
+.. include later - sending_changes.txt
+
+
+Un tour breve de los plugins mas populares
+##########################################
+
+.. include later - part2_intro.txt
+.. include later - bzrtools_plugin.txt
+.. include later - svn_plugin.txt
+.. include later looms_plugin.txt
+
+
+Integrando Bazaar en tu entorno
+###############################
+
+.. include later - web_browsing.txt
+.. include later - file_explorers.txt
+.. include later - desktop_integration.txt
+.. include later - editors_and_ides.txt
+.. include later - email.txt
+.. include later - bug_trackers.txt
+
+
+Temas varios
+############
+
+.. include later - adv_merging.txt
+.. include later - server.txt
+.. include later - hooks.txt
+.. include:: version_info.txt
+ 
+
+Apéndice
+########
+
+.. include later - specifying_revisions.txt
+.. include later - shared_repository_layouts.txt
+.. include later - setting_up_email.txt
+.. include later - http_smart_server.txt
+.. include later - writing_a_plugin.txt
+
+.. |--| unicode:: U+2014

=== modified file 'doc/es/user-guide/index.txt'
--- doc/es/user-guide/index.txt	2008-05-12 00:59:13 +0000
+++ doc/es/user-guide/index.txt	2009-09-08 01:19:48 +0000
@@ -10,9 +10,6 @@
 ..   level 3 ~~~~~~~~
 ..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
 
-.. contents:: :depth: 2
-.. sectnum::
-
 
 Introducción
 ############

=== removed directory 'doc/es/user-reference'
=== added file 'doc/index.es.txt'
--- doc/index.es.txt	1970-01-01 00:00:00 +0000
+++ doc/index.es.txt	2009-09-09 12:57:43 +0000
@@ -0,0 +1,46 @@
+==================================
+Indice de Documentacion de Bazaar
+==================================
+
+Las ultimas versiones de estos documentos se encuentran disponibles
+en la pagina de  Bazaar, http://doc.bazaar-vcs.org.
+
+Documentacion Principal
+=======================
+
+* `Mini Tutorial <es/mini-tutorial/index.html>`_ 
+
+* `Referencia Rapida <es/_static/es/bzr-es-quick-reference.svg>`_
+
+* `Guia de Usuario <es/user-guide/index-plain.html>`_ 
+
+* `Referencia <en/user-reference/bzr_man.html>`_ 
+
+* `Notas sobre la Version <en/release-notes/NEWS.html>`_
+
+* `Guia del Desarrollador <developers/HACKING.html>`_
+
+
+Otra Documentacion
+===================
+
+Mudandose a Bazaar (enlances web):
+
+* `Guias de Mudanzas <http://bazaar-vcs.org/BzrSwitching>`_ 
+  - para los usuarios que se mudan de otros SCV
+
+* `Guias de Migracion <http://bazaar-vcs.org/BzrMigration>`_
+  - para equipos que mudan el historial de otros SCV
+
+Otros Documentos (enlances web):
+
+* `Glosario <http://bazaar-vcs.org/BzrGlossary>`_
+
+* `Preguntas Frecuentes <http://bazaar-vcs.org/FAQ>`_
+
+* `Referencia del API bzrlib <http://bazaar-vcs.org/BzrLib>`_
+
+Especificaciones tecnicas, planes a futuro y varias
+notas tecnicas varias en Ingles:
+
+* `Catalogo de Documentos para Desarrolladores <developers/index.html>`_

=== added file 'doc/index.ru.txt'
--- doc/index.ru.txt	1970-01-01 00:00:00 +0000
+++ doc/index.ru.txt	2009-09-09 12:57:43 +0000
@@ -0,0 +1,63 @@
+=================================
+Главный каталог документов Bazaar
+=================================
+
+Последняя версия этих документов доступа со страницы документации 
+на сайте Bazaar, <http://doc.bazaar-vcs.org/>. Еще больше информации 
+можно получить по адресу <http://bazaar-vcs.org/Documentation>.
+
+Основная документация
+=====================
+
+* `Руководство пользователя <ru/user-guide/index-plain.html>`_
+
+* `Справочник пользователя <en/user-reference/bzr_man.html>`_ (англ.)
+
+* `Карточка быстрого старта <ru/_static/ru/bzr-ru-quick-reference.svg>`_
+  (`PDF <ru/_static/ru/bzr-ru-quick-reference.pdf>`_,
+  `PNG <ru/_static/ru/bzr-ru-quick-reference.png>`_)
+
+* `Список изменений <en/release-notes/NEWS.html>`_ (англ.)
+
+* `Каталог информации для разработчиков <developers/index-plain.html>`_ (англ.) |--| 
+  для разработчиков Bazaar и плагинов
+
+Учебники
+========
+
+* `Базар за пять минут <ru/mini-tutorial/index.html>`_
+
+* `Большой учебник <ru/tutorials/tutorial.html>`_
+
+* `Использование Bazaar с Launchpad 
+  <ru/tutorials/using_bazaar_with_launchpad.html>`_
+
+* `Работа в централизованном стиле
+  <ru/tutorials/centralized_workflow.html>`_
+
+Ссылки в сети
+=============
+
+* `Руководства по переходу <http://bazaar-vcs.org/BzrSwitching>`_
+  |--| для пользователей переходящих с других систем контроля версий
+
+* `Руководство по миграции <http://bazaar-vcs.org/BzrMigration>`_
+  |--| для команд переносящих историю с других систем контроля версий
+
+* `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.), 
+  см. также `русскую версию`__ 
+  
+__  http://groups.google.com/group/ru_bzr/web/%D0%B3%D0%BB%D0%BE%D1%81%D1%81%D0%B0%D1%80%D0%B8%D0%B9
+
+* `Часто задаваемые вопросы <http://bazaar-vcs.org/FAQ>`_ (англ.)
+
+Другие языки
+============
+
+* `Документация на английском <index.html>`_ |--| English Documentation
+* `Документация на испанском <index.es.html>`_
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/index.txt'
--- doc/index.txt	2009-08-10 06:53:44 +0000
+++ doc/index.txt	2009-09-10 02:09:26 +0000
@@ -9,13 +9,13 @@
 Core Documentation
 ==================
 
-* `User Guide <en/user-guide/index.html>`_ 
+* `User Guide <en/user-guide/index-plain.html>`_ 
 
 * `User Reference <en/user-reference/bzr_man.html>`_ 
 
-* `Quick Start Card <_static/en/quick-reference/bzr-quick-reference.svg>`_
-  (`PDF <_static/en/quick-reference/bzr-quick-reference.pdf>`_,
-  `PNG <_static/en/quick-reference/bzr-quick-reference.png>`_)
+* `Quick Start Card <en/_static/en/bzr-en-quick-reference.svg>`_
+  (`PDF <en/_static/en/bzr-en-quick-reference.pdf>`_,
+  `PNG <en/_static/en/bzr-en-quick-reference.png>`_)
 
 * `Release Notes <en/release-notes/NEWS.html>`_
 
@@ -37,7 +37,7 @@
 Developer Documentation
 =======================
 
-* `Developer Document Catalog <developers/index.html>`_ |--| for developers
+* `Developer Document Catalog <developers/index-plain.html>`_ |--| for developers
   of Bazaar and plugins
 
 Web links

=== added directory 'doc/ru/_static'
=== added file 'doc/ru/_static/bzr icon 16.png'
Binary files doc/ru/_static/bzr icon 16.png and doc/ru/_static/bzr icon 16.png differ
=== added file 'doc/ru/_static/bzr.ico'
Binary files doc/ru/_static/bzr.ico and doc/ru/_static/bzr.ico differ
=== added directory 'doc/ru/_static/ru'
=== renamed file 'doc/ru/quick-reference/Makefile' => 'doc/ru/_static/ru/Makefile'
--- doc/ru/quick-reference/Makefile	2008-08-19 06:29:48 +0000
+++ doc/ru/_static/ru/Makefile	2009-09-07 05:26:43 +0000
@@ -1,5 +1,5 @@
-TARGETS=quick-start-summary.png quick-start-summary.pdf
-OBJECTS=quick-start-summary.svg Makefile
+TARGETS=bzr-quick-reference.png bzr-quick-reference.pdf
+OBJECTS=bzr-quick-reference.svg Makefile
 
 all: $(TARGETS)
 
@@ -11,9 +11,9 @@
 .svg.png:
 	rsvg-convert -d 300 -p 300 -z 3.3346 -f png -o $@ $<
 
-bzr-quickref.png: $(OBJECTS)
+bzr-quick-reference.png: $(OBJECTS)
 
-bzr-quickref.pdf: $(OBJECTS)
+bzr-quick-reference.pdf: $(OBJECTS)
 
 clean:
 	rm -f $(TARGETS)

=== renamed file 'doc/ru/quick-reference/quick-start-summary.pdf' => 'doc/ru/_static/ru/bzr-ru-quick-reference.pdf'
=== renamed file 'doc/ru/quick-reference/quick-start-summary.png' => 'doc/ru/_static/ru/bzr-ru-quick-reference.png'
=== renamed file 'doc/ru/quick-reference/quick-start-summary.svg' => 'doc/ru/_static/ru/bzr-ru-quick-reference.svg'
=== added directory 'doc/ru/_templates'
=== added file 'doc/ru/_templates/layout.html'
--- doc/ru/_templates/layout.html	1970-01-01 00:00:00 +0000
+++ doc/ru/_templates/layout.html	2009-09-08 15:06:56 +0000
@@ -0,0 +1,8 @@
+{% extends "!layout.html" %}
+
+{% block rootrellink %}
+<li><a href="http://bazaar-vcs.org/">
+    <img src="{{ pathto("_static/bzr icon 16.png", 1) }}" /> Главная</a>&nbsp;|&nbsp;</li>
+<a href="http://doc.bazaar-vcs.org/ru/">Документация</a>&nbsp;|&nbsp;</li>
+{{ super() }}
+{% endblock %}

=== added file 'doc/ru/conf.py'
--- doc/ru/conf.py	1970-01-01 00:00:00 +0000
+++ doc/ru/conf.py	2009-09-09 15:51:18 +0000
@@ -0,0 +1,94 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# This file is execfile()d with the current directory set to its containing dir.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'ru'
+
+# Translations & supporting helper function
+bzr_titles = {
+        u'Table of Contents (%s)': u'Содержание (%s)',
+        u'Bazaar User Guide': None,
+        u'Bazaar User Reference': None,
+        u'Bazaar Release Notes': None,
+        u'Bazaar Upgrade Guide': None,
+        u'Bazaar in five minutes': u'Базар за пять минут',
+        u'Bazaar Tutorial': u'Большой учебник',
+        u'Using Bazaar With Launchpad': u'Использование Bazaar с Launchpad',
+        u'Centralized Workflow Tutorial': u'Работа в централизованном стиле',
+    }
+def bzr_title(s):
+    return bzr_titles.get(s) or s
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+language = bzr_locale
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+html_short_title = bzr_title(u"Table of Contents (%s)") % (release,)
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {'index': 'index.html'}
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-%s' % (bzr_locale,)
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = [
+  # Manuals
+  #('user-guide/index', 'bzr-%s-user-guide.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar User Guide'), bzr_team, 'manual'),
+  #('user-reference/bzr_man', 'bzr-%s-user-reference.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar User Reference'), bzr_team, 'manual'),
+  #('release-notes/NEWS', 'bzr-%s-release-notes.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Release Notes'), bzr_team, 'manual'),
+  #('upgrade-guide/index', 'bzr-%s-upgrade-guide.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Upgrade Guide'), bzr_team, 'manual'),
+  # Tutorials
+  ('mini-tutorial/index', 'bzr-%s-tutorial-mini.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar in five minutes'), bzr_team, 'howto'),
+  ('tutorials/tutorial', 'bzr-%s-tutorial.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar Tutorial'), bzr_team, 'howto'),
+  #('tutorials/using_bazaar_with_launchpad',
+  #  'bzr-%s-tutorial-with-launchpad.tex' % (bzr_locale,),
+  #  bzr_title(u'Using Bazaar With Launchpad'), bzr_team, 'howto'),
+  #('tutorials/centralized_workflow',
+  #  'bzr-%s-tutorial-centralized.tex' % (bzr_locale,),
+  #  bzr_title(u'Centralized Workflow Tutorial'), bzr_team, 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+unused_docs = [
+    # Subtopics that get included
+    'upgrade-guide/overview',
+    'upgrade-guide/data_migration',
+    'upgrade-guide/tips_and_tricks',
+    'user-guide/branching_a_project',
+    'user-guide/core_concepts',
+    'user-guide/introducing_bazaar',
+    'user-guide/specifying_revisions',
+    'user-guide/stacked',
+    'user-guide/using_checkouts',
+    'user-guide/zen',
+    # Plain-style documentation generation stuff
+    'user-guide/index-plain',
+]
+

=== renamed file 'doc/index.ru.txt' => 'doc/ru/index.txt'
--- doc/index.ru.txt	2009-06-02 18:07:12 +0000
+++ doc/ru/index.txt	2009-09-09 02:30:32 +0000
@@ -3,45 +3,26 @@
 =================================
 
 Последняя версия этих документов доступа со страницы документации 
-на сайте Bazaar, <http://doc.bazaar-vcs.org/>. Еще больше информации 
-можно получить по адресу <http://bazaar-vcs.org/Documentation>.
+на сайте Bazaar, <http://doc.bazaar-vcs.org/ru/>.
 
 Основная документация
 =====================
 
-* `Руководство пользователя <ru/user-guide/index.html>`_
-
-* `Справочник пользователя <en/user-reference/bzr_man.html>`_ (англ.)
-
-* `Карточка быстрого старта <ru/quick-reference/quick-start-summary.svg>`_
-  (`PDF <ru/quick-reference/quick-start-summary.pdf>`_,
-  `PNG <ru/quick-reference/quick-start-summary.png>`_)
-
-* `Список изменений <en/release-notes/NEWS.html>`_ (англ.)
-
-* `Каталог информации для разработчиков <developers/index.html>`_ (англ.) |--| 
-  для разработчиков Bazaar и плагинов
-
-Учебники
-========
-
-* `Базар за пять минут <ru/mini-tutorial/index.html>`_
-
-* `Большой учебник <ru/tutorials/tutorial.html>`_
-
-* `Использование Bazaar с Launchpad 
-  <ru/tutorials/using_bazaar_with_launchpad.html>`_
-
-* `Работа в централизованном стиле
-  <ru/tutorials/centralized_workflow.html>`_
+.. toctree::
+   :maxdepth: 1
+
+   user-guide/index
+   quick-reference/index
+   mini-tutorial/index
+   tutorials/tutorial
+   tutorials/using_bazaar_with_launchpad
+   tutorials/centralized_workflow
+
 
 Ссылки в сети
 =============
 
-* `Руководства по переходу <http://bazaar-vcs.org/BzrSwitching>`_
-  |--| для пользователей переходящих с других систем контроля версий
-
-* `Руководство по миграции <http://bazaar-vcs.org/BzrMigration>`_
+* `Руководство по миграции <http://doc.bazaar-vcs.org/migration/en/>`_
   |--| для команд переносящих историю с других систем контроля версий
 
 * `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.), 
@@ -49,13 +30,8 @@
   
 __  http://groups.google.com/group/ru_bzr/web/%D0%B3%D0%BB%D0%BE%D1%81%D1%81%D0%B0%D1%80%D0%B8%D0%B9
 
-* `Часто задаваемые вопросы <http://bazaar-vcs.org/FAQ>`_ (англ.)
-
-Другие языки
-============
-
-* `Документация на английском <index.html>`_ |--| English Documentation
-* `Документация на испанском <index.es.html>`_
+* `Часто задаваемые вопросы <https://answers.launchpad.net/bzr>`_ (англ.)
+
 
 .. |--| unicode:: U+2014
 

=== added file 'doc/ru/quick-reference/index.txt'
--- doc/ru/quick-reference/index.txt	1970-01-01 00:00:00 +0000
+++ doc/ru/quick-reference/index.txt	2009-09-09 02:32:10 +0000
@@ -0,0 +1,6 @@
+Карточка быстрого старта
+========================
+
+* `PDF <../_static/ru/bzr-ru-quick-reference.pdf>`_
+* `PNG <../_static/ru/bzr-ru-quick-reference.png>`_
+* `SVG <../_static/ru/bzr-ru-quick-reference.svg>`_

=== added file 'doc/ru/user-guide/index-plain.txt'
--- doc/ru/user-guide/index-plain.txt	1970-01-01 00:00:00 +0000
+++ doc/ru/user-guide/index-plain.txt	2009-09-09 12:57:43 +0000
@@ -0,0 +1,121 @@
+###############################
+Руководство пользователя Bazaar
+###############################
+
+.. Пожалуйста отмечайте секции в подключаемых файлах следующим образом:
+..   уровень 1 ========
+..   уровень 2 --------
+..   уровень 3 ~~~~~~~~
+..   уровень 4 ^^^^^^^^ (лучше не использовать вложенность больше 3-х уровней)
+
+.. contents::
+   Содержание
+   :depth: 2
+.. sectnum::
+
+
+Введение
+########
+
+.. include:: introducing_bazaar.txt
+.. include:: core_concepts.txt
+.. include:: ../../en/user-guide/bazaar_workflows.txt
+
+
+Начинаем работать
+#################
+
+.. include:: ../../en/user-guide/installing_bazaar.txt
+.. include:: ../../en/user-guide/entering_commands.txt
+.. include:: ../../en/user-guide/getting_help.txt
+.. include:: ../../en/user-guide/configuring_bazaar.txt
+.. include:: ../../en/user-guide/using_aliases.txt
+.. include:: ../../en/user-guide/plugins.txt
+.. include:: zen.txt
+
+
+Личный контроль версий
+######################
+
+.. include:: ../../en/user-guide/solo_intro.txt
+.. include:: ../../en/user-guide/starting_a_project.txt
+.. include:: ../../en/user-guide/controlling_registration.txt
+.. include:: ../../en/user-guide/reviewing_changes.txt
+.. include:: ../../en/user-guide/recording_changes.txt
+.. include:: ../../en/user-guide/browsing_history.txt
+.. include:: ../../en/user-guide/releasing_a_project.txt
+.. include:: ../../en/user-guide/undoing_mistakes.txt
+
+
+Делимся с другими
+#################
+
+.. include:: ../../en/user-guide/partner_intro.txt
+.. include:: branching_a_project.txt
+.. include:: ../../en/user-guide/merging_changes.txt
+.. include:: ../../en/user-guide/resolving_conflicts.txt
+.. include:: ../../en/user-guide/annotating_changes.txt
+
+
+Сотрудничество в команде, централизованный стиль
+################################################
+
+.. include:: ../../en/user-guide/central_intro.txt
+.. include:: ../../en/user-guide/publishing_a_branch.txt
+.. include:: using_checkouts.txt
+.. include:: ../../en/user-guide/working_offline_central.txt
+.. include:: ../../en/user-guide/reusing_a_checkout.txt
+
+
+Сотрудничество в команде, распределенный стиль
+##############################################
+
+.. include:: ../../en/user-guide/distributed_intro.txt
+.. include:: ../../en/user-guide/organizing_branches.txt
+.. include:: ../../en/user-guide/using_gatekeepers.txt
+.. include:: ../../en/user-guide/sending_changes.txt
+
+
+Различные темы
+##############
+
+.. include:: ../../en/user-guide/part2_intro.txt
+.. include:: ../../en/user-guide/adv_merging.txt
+.. include:: ../../en/user-guide/shelving_changes.txt
+.. include:: ../../en/user-guide/filtered_views.txt
+.. include:: stacked.txt
+.. include:: ../../en/user-guide/server.txt
+.. include:: ../../en/user-guide/hooks.txt
+.. include:: ../../en/user-guide/version_info.txt
+ 
+
+Краткое описание некоторых популярных плагинов
+##############################################
+
+.. include:: ../../en/user-guide/bzrtools_plugin.txt
+.. include:: ../../en/user-guide/svn_plugin.txt
+.. include later looms_plugin.txt
+
+
+Интегрируем Bazaar в нашу среду
+###############################
+
+.. include:: ../../en/user-guide/web_browsing.txt
+.. include later - file_explorers.txt
+.. include later - desktop_integration.txt
+.. include later - editors_and_ides.txt
+.. include later - email.txt
+.. include:: ../../en/user-guide/bug_trackers.txt
+
+
+Приложения
+##########
+
+.. include:: specifying_revisions.txt
+.. include:: ../../en/user-guide/organizing_your_workspace.txt
+.. include:: ../../en/user-guide/shared_repository_layouts.txt
+.. include:: ../../en/user-guide/setting_up_email.txt
+.. include:: ../../en/user-guide/http_smart_server.txt
+.. include:: ../../en/user-guide/writing_a_plugin.txt
+
+.. |--| unicode:: U+2014

=== added file 'tools/generate_release_notes.py'
--- tools/generate_release_notes.py	1970-01-01 00:00:00 +0000
+++ tools/generate_release_notes.py	2009-09-03 05:09:22 +0000
@@ -0,0 +1,86 @@
+#!/usr/bin/python
+
+# Copyright 2009 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+import os
+import sys
+from optparse import OptionParser
+
+sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))
+
+
+def split_into_topics(lines, out_file, out_dir):
+    """Split a large NEWS file into topics, one per release.
+
+    Releases are detected by matching headings that look like
+    release names. Topics are created with matching names
+    replacing spaces with dashes.
+    """
+    topic_file = None
+    for index, line in enumerate(lines):
+        maybe_new_topic = line[:4] in ['bzr ', 'bzr-0',]
+        if maybe_new_topic and lines[index + 1].startswith('####'):
+            release = line.strip()
+            if topic_file is None:
+                # First topic found
+                out_file.write(".. toctree::\n   :maxdepth: 1\n\n")
+            else:
+                # close the current topic
+                topic_file.close()
+            topic_file = open_topic_file(out_file, out_dir, release)
+        elif topic_file:
+            topic_file.write(line)
+        else:
+            # Still in the header - dump content straight to output
+            out_file.write(line)
+
+
+def open_topic_file(out_file, out_dir, release):
+    topic_name = release.replace(' ', '-')
+    out_file.write("   %s\n" % (topic_name,))
+    topic_path = os.path.join(out_dir, "%s.txt" % (topic_name,))
+    result = open(topic_path, 'w')
+    result.write("%s\n" % (release,))
+    return result
+
+
+def main(argv):
+    # Check usage
+    parser = OptionParser(usage="%prog SOURCE DESTINATION")
+    (options, args) = parser.parse_args(argv)
+    if len(args) != 2:
+        parser.print_help()
+        sys.exit(1)
+
+    # Open the files and do the work
+    infile_name = args[0]
+    outfile_name = args[1]
+    outdir = os.path.dirname(outfile_name)
+    infile = open(infile_name, 'r')
+    try:
+        lines = infile.readlines()
+    finally:
+        infile.close()
+    outfile = open(outfile_name, 'w')
+    try:
+        split_into_topics(lines, outfile, outdir)
+    finally:
+        outfile.close()
+
+
+if __name__ == '__main__':
+    main(sys.argv[1:])

=== added file 'tools/package_docs.py'
--- tools/package_docs.py	1970-01-01 00:00:00 +0000
+++ tools/package_docs.py	2009-09-09 00:49:50 +0000
@@ -0,0 +1,109 @@
+#!/usr/bin/python
+
+# Copyright 2009 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+import os
+import sys
+import tarfile
+from optparse import OptionParser
+from shutil import copy2, copytree, rmtree
+
+sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))
+
+
+def package_docs(section, src_build, dest_html, dest_downloads):
+    """Package docs from a Sphinx _build directory into target directories.
+
+    :param section: section in the website being built
+    :param src_build: the _build directory
+    :param dest_html: the directory where html should go
+    :param downloads: the directory where downloads should go
+    """
+    # Copy across the HTML. Explicitly delete the html destination
+    # directory first though because copytree insists on it not existing.
+    src_html = os.path.join(src_build, 'html')
+    if os.path.exists(dest_html):
+        rmtree(dest_html)
+    copytree(src_html, dest_html)
+
+    # Package the html as a downloadable archive
+    archive_root = "bzr-%s-html" % (section,)
+    archive_basename = "%s.tar.bz2" % (archive_root,)
+    archive_name = os.path.join(dest_downloads, archive_basename)
+    build_archive(src_html, archive_name, archive_root, 'bz2')
+
+    # Copy across the PDF docs, if any, including the quick ref card
+    pdf_files = []
+    quick_ref = os.path.join(src_html,
+        '_static/%s/bzr-%s-quick-reference.pdf' % (section, section))
+    if os.path.exists(quick_ref):
+        pdf_files.append(quick_ref)
+    src_pdf = os.path.join(src_build, 'latex')
+    if os.path.exists(src_pdf):
+        for name in os.listdir(src_pdf):
+            if name.endswith('.pdf'):
+                pdf_files.append(os.path.join(src_pdf, name))
+    if pdf_files:
+        dest_pdf = os.path.join(dest_downloads, 'pdf-%s' % (section,))
+        if not os.path.exists(dest_pdf):
+            os.mkdir(dest_pdf)
+        for pdf in pdf_files:
+            copy2(pdf, dest_pdf)
+
+    # TODO: copy across the CHM files, if any
+
+
+def build_archive(src_dir, archive_name, archive_root, format):
+    print "creating %s ..." % (archive_name,)
+    tar = tarfile.open(archive_name, "w:%s" % (format,))
+    for relpath in os.listdir(src_dir):
+        src_path = os.path.join(src_dir, relpath)
+        archive_path = os.path.join(archive_root, relpath)
+        tar.add(src_path, arcname=archive_path)
+    tar.close()
+
+
+def main(argv):
+    # Check usage. The first argument is the parent directory of
+    # the Sphinx _build directory. It will typically be 'doc/xx'.
+    # The second argument is the website build directory.
+    parser = OptionParser(usage="%prog SOURCE-DIR WEBSITE-BUILD-DIR")
+    (options, args) = parser.parse_args(argv)
+    if len(args) != 2:
+        parser.print_help()
+        sys.exit(1)
+
+    # Get the section - locale code or 'developers'
+    src_dir = args[0]
+    section = os.path.basename(src_dir)
+    src_build = os.path.join(src_dir, '_build')
+
+    # Create the destination directories if they doesn't exist.
+    dest_dir = args[1]
+    dest_html = os.path.join(dest_dir, section)
+    dest_downloads = os.path.join(dest_dir, 'downloads')
+    for d in [dest_dir, dest_downloads]:
+        if not os.path.exists(d):
+            print "creating directory %s ..." % (d,)
+            os.mkdir(d)
+
+    # Package and copy the files across
+    package_docs(section, src_build, dest_html, dest_downloads)
+
+
+if __name__ == '__main__':
+    main(sys.argv[1:])

